@@ -21,22 +21,29 @@
  * the two.
  */
 
+#include <cstdlib>
+#include <QDebug>
 #include <QTextStream>
 
 #include "src/cli/cli.h"
 #include "src/cli/cli_login.h"
-#include "src/gui/datovka.h"
 #include "src/io/account_db.h"
 #include "src/io/dbs.h"
 #include "src/io/filesystem.h"
 #include "src/io/isds_helper.h"
 #include "src/io/isds_sessions.h"
 #include "src/log/log.h"
+#include "src/model_interaction/account_interaction.h"
 #include "src/worker/pool.h"
 #include "src/worker/task_download_message.h"
 #include "src/worker/task_download_message_list.h"
 #include "src/worker/task_search_owner.h"
 
+const QSet<QString> serviceSet = QSet<QString>() << SER_LOGIN <<
+SER_GET_MSG_LIST << SER_SEND_MSG << SER_GET_MSG << SER_GET_DEL_INFO <<
+SER_GET_USER_INFO << SER_GET_OWNER_INFO << SER_CHECK_ATTACHMENT <<
+SER_GET_MSG_IDS << SER_FIND_DATABOX;
+
 // Known attributes definition
 const QStringList connectAttrs = QStringList()
     << "username" << "password" << "certificate" << "otpcode";
@@ -55,10 +62,10 @@ const QStringList getMsgAttrs = QStringList()
     << "attachmentDir";
 const QStringList getDelInfoAttrs = QStringList() << "dmID" << "zfoFile"
     << "download";
+const QStringList getMsgIdsAttrs = QStringList() << "dmType";
 const QStringList findDataboxAttrs = QStringList() << "dbType" << "dbID"
     << "ic" << "firmName" << "pnFirstName" << "pnLastName" << "adZipCode";
 
-
 /* ========================================================================= */
 static
 void printDataToStdOut(const QStringList &data)
@@ -99,7 +106,6 @@ void printErrToStdErr(const cli_error err, const QString errmsg)
 	cout << CLI_PREFIX << " error(" << err << ") : " << errmsg << endl;
 }
 
-
 /* ========================================================================= */
 const QString createErrorMsg(const QString &msg)
 /* ========================================================================= */
@@ -107,7 +113,6 @@ const QString createErrorMsg(const QString &msg)
 	return QString(CLI_PREFIX) + QString(PARSER_PREFIX) + msg;
 }
 
-
 /* ========================================================================= */
 static void isds_document_free_void(void **document)
 /* ========================================================================= */
@@ -115,7 +120,6 @@ static void isds_document_free_void(void **document)
 	isds_document_free((struct isds_document **) document);
 }
 
-
 /* ========================================================================= */
 bool checkAttributeIfExists(const QString &service, const QString &attribute)
 /* ========================================================================= */
@@ -130,13 +134,14 @@ bool checkAttributeIfExists(const QString &service, const QString &attribute)
 		return getMsgAttrs.contains(attribute);
 	} else if (service == SER_GET_DEL_INFO) {
 		return getDelInfoAttrs.contains(attribute);
+	} else if (service == SER_GET_MSG_IDS) {
+		return getMsgIdsAttrs.contains(attribute);
 	} else if (service == SER_FIND_DATABOX) {
 		return findDataboxAttrs.contains(attribute);
 	}
 	return false;
 }
 
-
 /* ========================================================================= */
 const QStringList parseAttachment(const QString &files)
 /* ========================================================================= */
@@ -147,7 +152,6 @@ const QStringList parseAttachment(const QString &files)
 	return files.split(";");
 }
 
-
 /* ========================================================================= */
 const QStringList parseDbIDRecipient(const QString &dbIDRecipient)
 /* ========================================================================= */
@@ -158,7 +162,6 @@ const QStringList parseDbIDRecipient(const QString &dbIDRecipient)
 	return dbIDRecipient.split(";");
 }
 
-
 /* ========================================================================= */
 cli_error getMsgList(const QMap<QString,QVariant> &map, MessageDbSet *msgDbSet,
     QString &errmsg)
@@ -310,7 +313,6 @@ cli_error getMsgList(const QMap<QString,QVariant> &map, MessageDbSet *msgDbSet,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error getMsg(const QMap<QString,QVariant> &map, MessageDbSet *msgDbSet,
     bool needsISDS, QString &errmsg)
@@ -473,7 +475,6 @@ cli_error getMsg(const QMap<QString,QVariant> &map, MessageDbSet *msgDbSet,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error getDeliveryInfo(const QMap<QString,QVariant> &map,
     MessageDbSet *msgDbSet, bool needsISDS, QString &errmsg)
@@ -552,7 +553,6 @@ cli_error getDeliveryInfo(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkAttachment(const QMap<QString,QVariant> &map,
     MessageDbSet *msgDbSet)
@@ -568,6 +568,34 @@ cli_error checkAttachment(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
+/* ========================================================================= */
+cli_error getMsgIds(const QMap<QString,QVariant> &map,
+    MessageDbSet *msgDbSet, QString &errmsg)
+/* ========================================================================= */
+{
+	const QString username = map["username"].toString();
+
+	qDebug() << CLI_PREFIX << "Get list of message IDs "
+	    "from local database for username" <<  username;
+
+	if ((map["dmType"].toString() != MT_RECEIVED) &&
+	    (map["dmType"].toString() != MT_SENT) &&
+	    (map["dmType"].toString() != MT_SENT_RECEIVED)) {
+		errmsg = "Wrong dmType value: " + map["dmType"].toString();
+		qDebug() << CLI_PREFIX << errmsg;
+		return CLI_ATR_VAL_ERR;
+	}
+
+	if (map["dmType"].toString() == MT_RECEIVED) {
+		printDataToStdOut(msgDbSet->getAllMessageIDs(MessageDb::TYPE_RECEIVED));
+	} else if (map["dmType"].toString() == MT_SENT) {
+		printDataToStdOut(msgDbSet->getAllMessageIDs(MessageDb::TYPE_SENT));
+	} else {
+		printDataToStdOut(msgDbSet->getAllMessageIDs(MessageDb::TYPE_RECEIVED));
+		printDataToStdOut(msgDbSet->getAllMessageIDs(MessageDb::TYPE_SENT));
+	}
+	return CLI_SUCCESS;
+}
 
 /* ========================================================================= */
 cli_error getUserInfo(const QMap<QString,QVariant> &map, QString &errmsg)
@@ -586,7 +614,6 @@ cli_error getUserInfo(const QMap<QString,QVariant> &map, QString &errmsg)
 	return CLI_ERROR;
 }
 
-
 /* ========================================================================= */
 cli_error getOwnerInfo(const QMap <QString, QVariant> &map, QString &errmsg)
 /* ========================================================================= */
@@ -604,7 +631,6 @@ cli_error getOwnerInfo(const QMap <QString, QVariant> &map, QString &errmsg)
 	return CLI_ERROR;
 }
 
-
 /* ========================================================================= */
 cli_error findDatabox(const QMap <QString, QVariant> &map, QString &errmsg)
 /* ========================================================================= */
@@ -659,7 +685,6 @@ cli_error findDatabox(const QMap <QString, QVariant> &map, QString &errmsg)
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 static
 struct isds_list *buildDocuments(const QStringList &filePaths)
@@ -1069,7 +1094,6 @@ finish:
 	return ret;
 }
 
-
 /* ========================================================================= */
 cli_error checkLoginMandatoryAttributes(const QMap<QString,QVariant> &map,
     QString &errmsg)
@@ -1089,7 +1113,6 @@ cli_error checkLoginMandatoryAttributes(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkSendMsgMandatoryAttributes(const QMap<QString,QVariant> &map,
     QString &errmsg)
@@ -1134,7 +1157,6 @@ cli_error checkSendMsgMandatoryAttributes(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkGetMsgListMandatoryAttributes(const QMap<QString,QVariant> &map,
     QString &errmsg)
@@ -1163,7 +1185,6 @@ cli_error checkGetMsgListMandatoryAttributes(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkGetMsgMandatoryAttributes(const QMap<QString,QVariant> &map,
     QString &errmsg)
@@ -1209,7 +1230,6 @@ cli_error checkGetMsgMandatoryAttributes(const QMap<QString,QVariant> &map,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkDownloadDeliveryMandatoryAttributes(
     const QMap<QString,QVariant> &map, QString &errmsg)
@@ -1241,7 +1261,6 @@ cli_error checkDownloadDeliveryMandatoryAttributes(
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkFindDataboxMandatoryAttributes(
     const QMap<QString,QVariant> &map, QString &errmsg)
@@ -1342,7 +1361,6 @@ cli_error checkFindDataboxMandatoryAttributes(
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error checkMandatoryAttributes(const QString &service,
     QMap<QString,QVariant> &map, QString &errmsg)
@@ -1358,6 +1376,8 @@ cli_error checkMandatoryAttributes(const QString &service,
 		return checkGetMsgMandatoryAttributes(map, errmsg);
 	} else if (service == SER_GET_DEL_INFO) {
 		return checkDownloadDeliveryMandatoryAttributes(map, errmsg);
+	} else if (service == SER_GET_MSG_IDS) {
+		return checkGetMsgListMandatoryAttributes(map, errmsg);
 	} else if (service == SER_FIND_DATABOX) {
 		return checkFindDataboxMandatoryAttributes(map, errmsg);
 	}
@@ -1365,7 +1385,6 @@ cli_error checkMandatoryAttributes(const QString &service,
 	return CLI_UNKNOWN_SER;
 }
 
-
 /* ========================================================================= */
 cli_error parsePamamString(const QString &service, const QString &paramString,
     QMap<QString,QVariant> &map, QString &errmsg)
@@ -1501,7 +1520,6 @@ cli_error parsePamamString(const QString &service, const QString &paramString,
 	return CLI_SUCCESS;
 }
 
-
 /* ========================================================================= */
 cli_error doService(const QString &service, const QMap<QString,QVariant> &map,
     MessageDbSet *msgDbSet, bool needsISDS, QString &errmsg)
@@ -1522,6 +1540,8 @@ cli_error doService(const QString &service, const QMap<QString,QVariant> &map,
 		return getOwnerInfo(map, errmsg);
 	} else if (service == SER_CHECK_ATTACHMENT) {
 		return checkAttachment(map, msgDbSet);
+	} else if (service == SER_GET_MSG_IDS) {
+		return getMsgIds(map, msgDbSet, errmsg);
 	} else if (service == SER_FIND_DATABOX) {
 		return findDatabox(map, errmsg);
 	}
@@ -1529,7 +1549,6 @@ cli_error doService(const QString &service, const QMap<QString,QVariant> &map,
 	return CLI_UNKNOWN_SER;
 }
 
-
 /* ========================================================================= */
 int runService(const QString &lParam,
     const QString &service, const QString &sParam)
@@ -1540,7 +1559,7 @@ int runService(const QString &lParam,
 	cli_error cret = CLI_ERROR;
 	bool needsISDS = true;
 	QString errmsg = "Unknown error";
-	int ret = CLI_EXIT_ERROR;
+	int ret = EXIT_FAILURE;
 
 	/* parse service parameter list */
 	if (!(service.isNull()) && !(sParam.isNull())) {
@@ -1570,7 +1589,13 @@ int runService(const QString &lParam,
 	const QString username = loginMap["username"].toString();
 
 	/* get message database set */
-	MessageDbSet *msgDbSet = MainWindow::accountDbSet(username, 0);
+	MessageDbSet *msgDbSet = Q_NULLPTR;
+	{
+		enum AccountInteraction::AccessStatus status;
+		QString dbDir, namesStr;
+		msgDbSet = AccountInteraction::accessDbSet(username, status,
+		    dbDir, namesStr);
+	}
 	if (msgDbSet == NULL) {
 		errmsg = "Database doesn't exists for user " + username;
 		qDebug() << CLI_PREFIX << errmsg;
@@ -1646,7 +1671,7 @@ int runService(const QString &lParam,
 		}
 	}
 
-	if (service == SER_CHECK_ATTACHMENT) {
+	if (service == SER_CHECK_ATTACHMENT || service == SER_GET_MSG_IDS) {
 		needsISDS = false;
 	}
 
@@ -1665,7 +1690,7 @@ int runService(const QString &lParam,
 
 		if (!globIsdsSessions.isConnectedToIsds(username) &&
 		    !connectToIsdsCLI(globIsdsSessions,
-			    AccountModel::globAccounts[username], pwd, otp)) {
+		        globAccounts[username], pwd, otp)) {
 			errmsg = "Missing session for " + username +
 			   " or connection fails";
 			qDebug() << errmsg;
@@ -1685,7 +1710,7 @@ int runService(const QString &lParam,
 	}
 
 	if (CLI_SUCCESS == cret) {
-		ret = CLI_EXIT_OK;
+		ret = EXIT_SUCCESS;
 	} else {
 		printErrToStdErr(cret, errmsg);
 	}
