@@ -52,21 +52,18 @@
 #define CZ_NIC_URL "https://www.nic.cz"
 #define DATOVKA_ONLINE_HELP_URL "https://secure.nic.cz/files/datove_schranky/redirect/prirucka.html"
 #define DATOVKA_FAQ_URL "https://secure.nic.cz/files/datove_schranky/redirect/faq.html"
-#define DATOVKA_HOMEPAGE_URL "https://labs.nic.cz/cs/datovka.html"
+#define DATOVKA_HOMEPAGE_URL "https://www.datovka.cz/"
 #define DATOVKA_CHECK_NEW_VERSION_URL "https://secure.nic.cz/files/datove_schranky/Version"
-#define DATOVKA_DOWNLOAD_URL "https://labs.nic.cz/cs/datovka.html"
+#define DATOVKA_DOWNLOAD_URL "https://www.datovka.cz/"
 #define PWD_EXPIRATION_NOTIFICATION_DAYS 7 // show expiration date dialog before xx days
 
-#define DB_MOJEID_NAME_PREFIX "mojeid-"
-
 /* return values of Datovka login methods */
 typedef enum {
 	USER_NAME = 0,
 	CERTIFICATE = 1,
 	USER_CERTIFICATE = 2,
 	HOTP = 3,
-	TOTP = 4,
-	MOJEID = 5
+	TOTP = 4
 } LoginMethodsIndex;
 
 
@@ -118,29 +115,38 @@ enum MessageDirection {
                                                    * are displayed as icons.
                                                    */
 
+/* Expecting arguments of type QString. */
+#define strongAccountInfoLineNoEscape(title, value) \
+	(QLatin1String("<div><strong>") + (title) + \
+	QLatin1String(": </strong>") + (value) + \
+	QLatin1String("</div>"))
 #define strongAccountInfoLine(title, value) \
-	(QString("<div><strong>") + (title) + ": </strong>" + (value) + \
-	"</div>")
+	(QLatin1String("<div><strong>") + (title).toHtmlEscaped() + \
+	QLatin1String(": </strong>") + (value).toHtmlEscaped() + \
+	QLatin1String("</div>"))
 #define accountInfoLine(title, value) \
-	(QString("<div>") + (title) + ": " + (value) + "</div>")
-#define indentDivStart "<div style=\"margin-left: 12px;\">"
-#define divEnd "</div>"
+	(QLatin1String("<div>") + (title).toHtmlEscaped() + \
+	QLatin1String(": ") + (value).toHtmlEscaped() + QLatin1String("</div>"))
+#define indentDivStart QLatin1String("<div style=\"margin-left: 12px;\">")
+#define divEnd QLatin1String("</div>")
 
 #define strongMessagePdf(title) \
-	(QString("<strong>") + (title) + QString("</strong>"))
+	(QLatin1String("<strong>") + (title).toHtmlEscaped() + \
+	QLatin1String("</strong>"))
 
 #define messageTableSectionPdf(title) \
-	(QString("<table width=\"100%\" style=\"background-color: #FFFF00; padding: 40px 20px 40px 20px; font-size: 18px;\"><tr><td>") + \
-	title + QString("</td></tr></table>"))
+	(QLatin1String("<table width=\"100%\" style=\"background-color: #FFFF00; padding: 40px 20px 40px 20px; font-size: 18px;\"><tr><td>") + \
+	(title).toHtmlEscaped() + QLatin1String("</td></tr></table>"))
 
 #define messageTableInfoStartPdf() \
-	(QString("<table style=\"margin-left: 10px; margin-top: 10px; margin-bottom: 30px; font-size: 16px;\">"))
+	(QLatin1String("<table style=\"margin-left: 10px; margin-top: 10px; margin-bottom: 30px; font-size: 16px;\">"))
 
 #define messageTableInfoPdf(title, value) \
-	(QString("<tr><td>") + title + QString(": ") + \
-	QString("</td><td>") + value + QString("</td></tr>"))
+	(QLatin1String("<tr><td>") + (title).toHtmlEscaped() + \
+	QLatin1String(": ") + QLatin1String("</td><td>") + \
+	(value).toHtmlEscaped() + QLatin1String("</td></tr>"))
 
-#define messageTableInfoEndPdf() (QString("</table>"))
+#define messageTableInfoEndPdf() (QLatin1String("</table>"))
 
 /*!
  * @brief Date/time format used in the application.
@@ -161,14 +167,6 @@ const QString dateDisplayFormat;
 void addAttachmentToEmailMessage(QString &message, const QString &attachName,
     const QByteArray &base64, const QString &boundary);
 
-/*!
- * @brief Translates author type to text.
- *
- * @param[in] authorType Author type string.
- * @return Author type description.
- */
-const QString authorTypeToText(const QString &authorType);
-
 /*!
  * @brief Computes the size of real (decoded from base64) data.
  *
@@ -177,94 +175,6 @@ const QString authorTypeToText(const QString &authorType);
  */
 int base64RealSize(const QByteArray &b64);
 
-/*!
- * @brief Return attachment type as string.
- *
- * @param[in] value Attachment type value.
- * @return Attachment type description.
- */
-QString convertAttachmentType(int value);
-
-/*!
- * @brief Convert type of databox to int.
- *
- * @param[in] value databox type string.
- * @return databox int.
- */
-int convertDbTypeToInt(QString value);
-
-/*!
- * @brief Convert type of databox to string.
- *
- * @param[in] value databox type value.
- * @return Databox type description.
- */
-QString convertDbTypeToString(int value);
-
-/*!
- * @brief Convert event type to string.
- *
- * @param[in] value event type value.
- * @return Event description.
- */
-QString convertEventTypeToString(int value);
-
-/*!
- * @brief Return hash algorithm as string.
- *
- * @param[in] value Hash algorithm value.
- * @return Hash algorithm type string.
- */
-QString convertHashAlg(int value);
-
- /*!
- * @brief Return hash algorithm as int.
- *
- * @param[in] value Hash algorithm string.
- * @return Hash algorithm type value.
- */
-int convertHashAlg2(QString value);
-
-/*!
- * @brief Return dec index from hex.
- *
- * @param[in] value Decadical value.
- * @return Hexadecimal value.
- */
-int convertHexToDecIndex(int value);
-
-/*!
- * @brief Return sender databox type as string from number representation.
- *
- * @param[in] value Sender databox type value.
- * @return Sender databox type description.
- */
-QString convertSenderDbTypesToString(int value);
-
-/*!
- * @brief Convert type of author to string.
- *
- * @param[in] value Author type value.
- * @return Author type description.
- */
-QString convertSenderTypeToString(int value);
-
-/*!
- * @brief Return privilegs as html string from number representation.
- *
- * @param[in] userPrivils Privilegy value.
- * @return Privilegy description.
- */
-QString convertUserPrivilsToString(int userPrivils);
-
-/*!
- * Convert type of user to string.
- *
- * @param[in] value user type value.
- * @return User description.
- */
-const QString & convertUserTypeToString(int value);
-
 /*!
  * @brief Creates email header and message body.
  *
@@ -275,14 +185,6 @@ const QString & convertUserTypeToString(int value);
 void createEmailMessage(QString &message, const QString &subj,
     const QString &boundary);
 
-/*!
- * @brief Translates message type to text.
- *
- * @param[in] dmType Message type value.
- * @return Message type description.
- */
-const QString dmTypeToText(const QString &dmType);
-
 /*!
  * @brief Adds last line into email.
  *
@@ -299,47 +201,6 @@ void finishEmailMessage(QString &message, const QString &boundary);
  */
 QString fromBase64(const QString &base64);
 
-/*!
- * @brief Convert state box to text
- *
- * @param[in] value databox status value.
- * @return Databox status string.
- */
-QString getdbStateText(int value);
-
-/*!
- * @brief Get/create WebDatovka (MojeId) username.
- *
- * @param[in] userId    Wedatovka user ID.
- * @param[in] accountId Wedatovka account ID.
- * @return Username of account.
- */
-QString getWebDatovkaUsername(const QString &userId, const QString &accountId);
-
-/*!
- * Get account id from username of WebDatovka account.
- *
- * @param[in] userName Account user name.
- * @return Account id of webdatovka account.
- */
-int getWebDatovkaAccountId(const QString &userName);
-
-/*!
- * Get user id from username of WebDatovka account.
- *
- * @param[in] userName Account user name.
- * @return user id of webdatovka account.
- */
-int getWebDatovkaUserId(const QString &userName);
-
-/*!
- * Get name prefix of tag database from username (WebDatovka).
- *
- * @param[in] userName  Account user name.
- * @return tag database prefix of webdatovka account.
- */
-QString getWebDatovkaTagDbPrefix(const QString &userName);
-
 /*!
  * @brief Check valid database filename.
  *
@@ -353,22 +214,6 @@ QString getWebDatovkaTagDbPrefix(const QString &userName);
 bool isValidDatabaseFileName(QString inDbFileName, QString &dbUserName,
     QString &dbYear, bool &dbTestingFlag, QString &errMsg);
 
-/*!
- * @brief Test if selected account is WebDatovka (MojeId) account.
- *
- * @param[in] userName  Account user name.
- * @return true if account is webdatovka account.
- */
-bool isWebDatovkaAccount(const QString &userName);
-
-/*!
- * @brief Returns message status description.
- *
- * @param[in] status Message status value.
- * @return message status description.
- */
-const QString msgStatusToText(int status);
-
 /*!
  * @brief Converts string to base64.
  *
