@@ -24,7 +24,6 @@
 #ifndef _DATOVKA_H_
 #define _DATOVKA_H_
 
-
 #include <QItemSelection>
 #include <QLabel>
 #include <QLineEdit>
@@ -44,10 +43,11 @@
 #include "src/gui/dlg_import_zfo.h"
 #include "src/gui/dlg_timestamp_expir.h"
 #include "src/models/accounts_model.h"
+#include "src/models/files_model.h"
+#include "src/models/messages_model.h"
 #include "src/models/sort_filter_proxy_model.h"
 #include "src/settings/preferences.h"
 #include "src/single/single_instance.h"
-#include "src/web/json.h"
 #include "src/worker/task.h" /* TODO -- remove this header file. */
 
 /* Forward declaration as we don;t wan to pull-in all header file content. */
@@ -57,20 +57,13 @@ namespace Ui {
 	class MainWindow;
 }
 
-
 class MainWindow : public QMainWindow {
 	Q_OBJECT
 
 public:
-	explicit MainWindow(QWidget *parent = 0);
+	explicit MainWindow(QWidget *parent = Q_NULLPTR);
 	~MainWindow(void);
 
-	/*!
-	 * @brief Create configuration file if not present.
-	 */
-	static
-	bool ensureConfPresence(void);
-
 	/*!
 	 * @brief Connects to ISDS and downloads basic information about the
 	 *     user.
@@ -82,20 +75,9 @@ public:
 	/*!
 	 * @brief Get message db set related to given account.
 	 *
-	 * @note If pointer to main window is not specified, then all dialogues
-	 *     will be suppressed.
-	 *
 	 * @param userName Account login.
-	 * @param mw       Pointer to main window.
 	 */
-	static
-	MessageDbSet *accountDbSet(const QString &userName, MainWindow *mw);
-
-	/*!
-	 * @brief Get account list from Webdatovka.
-	 */
-	bool wdGetAccountList(const QString &userName,
-	    const QNetworkCookie &sessionid, bool syncWithAll);
+	MessageDbSet *accountDbSet(const QString &userName);
 
 protected:
 	/*!
@@ -119,18 +101,11 @@ protected:
 
 	/*!
 	 * @brief Check window geometry, adjust size if window is too large for
-	 *     desktop..
+	 *     desktop.
 	 */
 	virtual
 	void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
 
-public slots:
-
-	/*!
-	 * @brief Login to mojeID.
-	 */
-	void loginToMojeId(const QString &userName);
-
 private slots:
 	/*!
 	 * @brief Refresh AccountList.
@@ -155,14 +130,6 @@ private slots:
 	    const QDateTime &deliveryTime, int result, const QString &errDesc,
 	    bool listScheduled);
 
-	/*!
-	 * @brief Performs action depending on message download outcome
-	 *        for webdatovka.
-	 */
-	void collectDownloadMessageMojeId(const QString &usrName,
-	    qint64 msgId, int result, const QString &errDesc,
-	    bool listScheduled);
-
 	/*!
 	 * @brief Performs action depending on message list download outcome.
 	 */
@@ -184,12 +151,6 @@ private slots:
 	    const QString &dbIDRecipient, const QString &recipientName,
 	    bool isPDZ, qint64 dmId);
 
-	/*!
-	 * @brief Performs action depending on webdatovka message send outcome.
-	 */
-	void sendMessageMojeIdAction(const QString &userName,
-	    const QStringList &result, const QString &error);
-
 	/*!
 	 * @brief Version response slot.
 	 */
@@ -398,11 +359,6 @@ private slots:
 	 */
 	void deleteMessage(void);
 
-	/*!
-	 * @brief Delete selected message(s) from local database and Webdatovka.
-	 */
-	void deleteMessageWebdatovka(const QString &userName);
-
 	/*!
 	 * @brief Downloads new messages from server for all accounts.
 	 */
@@ -419,7 +375,7 @@ private slots:
 	bool synchroniseSelectedAccount(QString userName = QString());
 
 	/*!
-	 * @brief Downloads the attachments for the selected message.
+	 * @brief Downloads attachments of selected messages.
 	 */
 	void downloadSelectedMessageAttachments(void);
 
@@ -469,11 +425,6 @@ private slots:
 	 */
 	void showAddNewAccountDialog(void);
 
-	/*!
-	 * @brief Add mojeID account action and dialog.
-	 */
-	void addNewMojeIDAccount(void);
-
 	/*!
 	 * @brief Deletion confirmation dialog.
 	 */
@@ -489,11 +440,6 @@ private slots:
 	 */
 	void showImportDatabaseDialog(void);
 
-	/*!
-	 * @brief Prepare import database directory.
-	 */
-	void prepareCreateAccountFromDatabaseFile(bool fromDirectory);
-
 	/*!
 	 * @brief Prepare import of messages from database.
 	 */
@@ -504,6 +450,11 @@ private slots:
 	 */
 	void showProxySettingsDialog(void);
 
+	/*!
+	 * @brief Records management dialogue.
+	 */
+	void showRecordsManagementDialogue(void);
+
 	/*!
 	 * @brief Move selected account up.
 	 */
@@ -575,6 +526,17 @@ private slots:
 	 */
 	void openDeliveryInfoExternally(void);
 
+	/*!
+	 * @brief Obtain information about stored messages from records
+	 *     management.
+	 */
+	void getStoredMsgInfoFromRecordsManagement(void);
+
+	/*!
+	 * @brief Send message to records management.
+	 */
+	void sendSelectedMessageToRecordsManagement(void);
+
 	/*!
 	 * @brief Search data box dialog.
 	 */
@@ -615,11 +577,6 @@ private slots:
 	 */
 	void goHome(void);
 
-	/*!
-	 * @brief Clear message filter field.
-	 */
-	void clearFilterField(void);
-
 	/*!
 	 * @brief Filter listed messages.
 	 */
@@ -660,13 +617,6 @@ private slots:
 	 */
 	void setWindowsAfterInit(void);
 
-	/*!
-	 * @brief Receive and store new account database path. Change data
-	 *     directory path in settings.
-	 */
-	void receiveNewDataPath(QString oldDir, QString newDir,
-	    QString action);
-
 	/*!
 	 * @brief set message process state into db
 	 */
@@ -718,10 +668,6 @@ private slots:
 	 */
 	void vacuumMsgDbSlot(void);
 
-	void callMojeId(const QString &user, const QString &lastUrl,
-	    const QString &token, QString userName, QString pwd, QString otp,
-	    bool syncALL, const QString &certPath);
-
 	/*!
 	 * @brief Show information about import message results.
 	 */
@@ -742,21 +688,8 @@ private:
 	 * @param[in] userName Account login string. Must be supplied when
 	 *                     message identifiers are passed.
 	 * @param[in] msgIdList Messages whose tags should be edited.
-	 * @param[in] msgIdWebDatovkaList Webdatovka messages whose tags should
-	 *                                be edited.
 	 */
-	void modifyTags(const QString &userName, QList<qint64> msgIdList,
-	    QList<qint64> msgIdWebDatovkaList);
-
-	/*!
-	 * @brief Get message list from webdatovka server.
-	 */
-	bool wdGetMessageList(const QString &userName);
-
-	/*!
-	 * @brief Do sync of account in the webdatovka server.
-	 */
-	bool wdSyncAccount(const QString &userName);
+	void modifyTags(const QString &userName, QList<qint64> msgIdList);
 
 	/*!
 	 * @brief Show status bar text with timeout.
@@ -806,11 +739,6 @@ private:
 	QModelIndex accountYearlyIndex(const QString &userName,
 	    const QString &year, int msgType);
 
-	/*!
-	 * @brief Return index for message with given properties.
-	 */
-	QModelIndex messageIndex(qint64 msgId) const;
-
 	/*!
 	 * @brief Check message time stamp expiration for account.
 	 */
@@ -1060,12 +988,6 @@ private:
 	 */
 	void checkNewDatovkaVersion(void);
 
-	/*!
-	 * @brief Sent and check a new version of Datovka.
-	 */
-	void createAccountFromDatabaseFileList(
-	    const QStringList &filePathList);
-
 	/*!
 	 * @brief Download complete message synchronously
 	 * without worker and thread.
@@ -1114,23 +1036,6 @@ private:
 	void exportExpirMessagesToZFO(const QString &userName,
 	    const QList<MessageDb::MsgId> &expirMsgIds);
 
-	/*!
-	 * @brief Show dialog for webdatovka account
-	 *        that action is not implemented.
-	 * @param[in] userName - account username.
-	 * @param[in] txt        additional info text.
-	 */
-	void showWebDatovkaInfoDialog(const QString &userName, QString txt);
-
-	/*!
-	 * @brief Test if exists another mojeID account with same userId
-	 *        when we delete any mojeID acccount.
-	 *
-	 * @param[in] userName - account username.
-	 * @return true if any account exists
-	 */
-	bool existsAnotherMojeIdAccountWithSameUserId(const QString &userName);
-
 	/*!
 	 * @brief Export selected messages to disk.
 	 *
@@ -1153,10 +1058,12 @@ private:
 	                              * Account tree view model. Generated from
 	                              * configuration file.
 	                              */
+	DbMsgsTblModel m_messageTableModel; /*!< Message table model. */
 	SortFilterProxyModel m_messageListProxyModel; /*!<
 	                                               * Used for message
 	                                               * sorting and filtering.
 	                                               */
+	DbFlsTblModel m_attachmentModel; /*! Attachment table model. */
 
 	QTimer m_messageMarker; /*!< Used for marking messages as read. */
 	qint64 m_lastSelectedMessageId; /*!< Id of the last selected message. */
@@ -1182,7 +1089,7 @@ private:
 	QString m_import_zfo_path;
 	QRect m_geometry; /* Non-maximised window geometry. */
 
-	QStringList m_msgTblAppendedCols; /*< Appended columns. */
+	QList<DbMsgsTblModel::AppendedCol> m_msgTblAppendedCols; /*< Appended columns. */
 
 	QSet<QString> m_zfoFilesToImport; /*!< Set of files to be imported. */
 	int m_numFilesToImport; /*!< Input ZFO count. */
@@ -1196,7 +1103,6 @@ private:
 	/* User interface elements. */
 	Ui::MainWindow *ui; /*!< User interface as generated from ui files. */
 	QLineEdit *mui_filterLine; /*!< Search filter line object. */
-	QPushButton *mui_clearFilterLineButton; /*!< Clear filter button. */
 	QStatusBar *mui_statusBar; /*!< Status bar. */
 	QLabel *mui_statusDbMode; /*!< Database status label. */
 	QLabel *mui_statusOnlineLabel; /*< On-line/off-line status label. */
