@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,27 +21,19 @@
  * the two.
  */
 
-#if defined(__APPLE__) || defined(__clang__)
-#  define __USE_C99_MATH
-#  define _Bool bool
-#else /* !__APPLE__ */
-#  include <cstdbool>
-#endif /* __APPLE__ */
-
-#include <cstdlib>
-#include <isds.h>
-#include <openssl/crypto.h> /* SSLeay_version(3) */
-#include <QFile>
-
+#include "src/about.h"
+#include "src/common.h"
 #include "src/gui/dlg_about.h"
 #include "src/io/filesystem.h"
+#include "ui_dlg_about.h"
 
 DlgAbout::DlgAbout(QWidget *parent)
-    : QDialog(parent)
+    : QDialog(parent),
+    m_ui(new (std::nothrow) Ui::DlgAbout)
 {
-	setupUi(this);
+	m_ui->setupUi(this);
 
-	this->labelVersion->setText(
+	m_ui->labelVersion->setText(
 	    "<span style=\"font-size:15pt;\"><b>Datovka"
 #ifdef PORTABLE_APPLICATION
 	    " - " + tr("Portable version") +
@@ -51,12 +43,12 @@ DlgAbout::DlgAbout(QWidget *parent)
 	    "<b>" + tr("Version") + ": " VERSION "</b>"
 	    "<br/>"
 	    + tr("Free client for Czech eGov data boxes."));
-	this->labelVersion->setAlignment(Qt::AlignHCenter);
-	this->labelVersion->setTextFormat(Qt::RichText);
-	this->labelVersion->setTextInteractionFlags(Qt::TextBrowserInteraction);
+	m_ui->labelVersion->setAlignment(Qt::AlignHCenter);
+	m_ui->labelVersion->setTextFormat(Qt::RichText);
+	m_ui->labelVersion->setTextInteractionFlags(Qt::TextBrowserInteraction);
 
 	QString copyrightHtml(
-	    "Copyright &copy; 2014–2016 CZ.NIC, z. s. p. o. "
+	    "Copyright &copy; 2014–2017 CZ.NIC, z. s. p. o. "
 	    "&lt;<a href=\"" CZ_NIC_URL "\">" CZ_NIC_URL "</a>&gt;");
 	copyrightHtml += "<br/>" + tr("Additional informations") + ": "
 	    "<a href=\"" DATOVKA_HOMEPAGE_URL "\">" + tr("home page") + "</a>"
@@ -66,52 +58,58 @@ DlgAbout::DlgAbout(QWidget *parent)
 	    "<a href=\"" DATOVKA_FAQ_URL "\">" + tr("FAQ") + "</a>";
 	copyrightHtml += "<br/>" + tr("Support") + ": "
 	    "&lt;<a href=\"mailto:" SUPPORT_MAIL "?Subject=[Datovka%20" VERSION "]\">" SUPPORT_MAIL "</a>&gt;";
-	this->labelCopy->setText(copyrightHtml);
-	this->labelCopy->setTextFormat(Qt::RichText);
-	this->labelCopy->setTextInteractionFlags(Qt::TextBrowserInteraction);
-	this->labelCopy->setOpenExternalLinks(true);
+	m_ui->labelCopy->setText(copyrightHtml);
+	m_ui->labelCopy->setTextFormat(Qt::RichText);
+	m_ui->labelCopy->setTextInteractionFlags(Qt::TextBrowserInteraction);
+	m_ui->labelCopy->setOpenExternalLinks(true);
 
 	QString librariesStr("<b>");
 	librariesStr += QObject::tr("Depends on libraries:");
 	librariesStr += "</b><br/>";
-	this->labelLibs->setText(librariesStr +
+	m_ui->labelLibs->setText(librariesStr +
 	    libraryDependencies().join("<br/>"));
-	this->labelLibs->setTextFormat(Qt::RichText);
-	this->labelLibs->setTextInteractionFlags(Qt::TextBrowserInteraction);
-	this->labelLibs->setAlignment(Qt::AlignHCenter);
-	this->labelLibs->setWordWrap(true);
+	m_ui->labelLibs->setTextFormat(Qt::RichText);
+	m_ui->labelLibs->setTextInteractionFlags(Qt::TextBrowserInteraction);
+	m_ui->labelLibs->setAlignment(Qt::AlignHCenter);
+	m_ui->labelLibs->setWordWrap(true);
 
-	connect(this->pushButtonLicence, SIGNAL(clicked()), this,
+	connect(m_ui->pushButtonLicence, SIGNAL(clicked()), this,
 	    SLOT(showLicence()));
-	connect(this->pushButtonCredits, SIGNAL(clicked()), this,
+	connect(m_ui->pushButtonCredits, SIGNAL(clicked()), this,
 	    SLOT(showCredits()));
 
-	connect(this->buttonBox, SIGNAL(accepted()), this, SLOT(close()));
+	connect(m_ui->buttonBox, SIGNAL(accepted()), this, SLOT(close()));
 }
 
-QStringList DlgAbout::libraryDependencies(void)
+DlgAbout::~DlgAbout(void)
 {
-	QStringList libs;
+	delete m_ui;
+}
 
-	libs.append(QStringLiteral("Qt ") + qVersion());
-
-	char *isdsVer = isds_version();
-	libs.append(QStringLiteral("libisds ") + isdsVer);
-	free(isdsVer); isdsVer = NULL;
-
-	libs.append(SSLeay_version(SSLEAY_VERSION));
-
-	return libs;
+void DlgAbout::about(QWidget *parent)
+{
+	DlgAbout dlg(parent);
+	dlg.exec();
 }
 
 void DlgAbout::showLicence(void)
 {
-	this->textEdit->setPlainText(
+	m_ui->textEdit->setPlainText(
 	    suppliedTextFileContent(TEXT_FILE_LICENCE));
+	if (m_ui->textEdit->toPlainText().isEmpty()) {
+		m_ui->textEdit->setPlainText(
+		    tr("File '%1' either doesn't exist or is empty.")
+		        .arg(expectedTextFilePath(TEXT_FILE_LICENCE)));
+	}
 }
 
 void DlgAbout::showCredits(void)
 {
-	this->textEdit->setPlainText(
+	m_ui->textEdit->setPlainText(
 	    suppliedTextFileContent(TEXT_FILE_CREDITS));
+	if (m_ui->textEdit->toPlainText().isEmpty()) {
+		m_ui->textEdit->setPlainText(
+		    tr("File '%1' either doesn't exist or is empty.")
+		        .arg(expectedTextFilePath(TEXT_FILE_CREDITS)));
+	}
 }
