@@ -27,10 +27,12 @@
 #include <QPushButton>
 #include <QTextStream>
 
+#include "src/delegates/tag_item.h"
 #include "src/gui/dlg_correspondence_overview.h"
+#include "src/gui/dlg_msg_box_informative.h"
 #include "src/io/exports.h"
 #include "src/io/filesystem.h"
-#include "src/models/accounts_model.h"
+#include "src/settings/accounts.h"
 #include "src/settings/preferences.h"
 
 #define CSV_LITERAL QStringLiteral("CSV")
@@ -48,8 +50,7 @@ DlgCorrespondenceOverview::DlgCorrespondenceOverview(const MessageDbSet &dbSet,
 
 	Q_ASSERT(!userName.isEmpty());
 
-	this->accountName->setText(
-	    AccountModel::globAccounts[userName].accountName() +
+	this->accountName->setText(globAccounts[userName].accountName() +
 	    QStringLiteral(" (") + userName + QStringLiteral(")"));
 
 	this->toCalendarWidget->setMinimumDate(this->fromCalendarWidget->selectedDate());
@@ -507,28 +508,28 @@ void appendError(enum Exports::ExportFileType fileType, qint64 dmId,
 {
 	switch (fileType) {
 	case Exports::ZFO_MESSAGE:
-		qWarning(
+		qWarning("%s",
 		    QString("DZ '%1' export error.").arg(dmId).toUtf8().constData());
 		errList.append(
 		    QObject::tr("Message '%1' does not contain data necessary for ZFO export.")
 		        .arg(dmId));
 		break;
 	case Exports::ZFO_DELIVERY:
-		qWarning(
+		qWarning("%s",
 		    QString("DZ '%1' export error").arg(dmId).toUtf8().constData());
 		errList.append(
 		    QObject::tr("Message '%1' does not contain acceptance info data necessary for ZFO export.")
 		        .arg(dmId));
 		break;
 	case Exports::PDF_ENVELOPE:
-		qWarning(
+		qWarning("%s",
 		    QString("OZ '%1' export error").arg(dmId).toUtf8().constData());
 		errList.append(
 		    QObject::tr("Message '%1' does not contain message envelope data necessary for PDF export.")
 		        .arg(dmId));
 		break;
 	case Exports::PDF_DELIVERY:
-		qWarning(
+		qWarning("%s",
 		    QString("DD '%1' export error").arg(dmId).toUtf8().constData());
 		errList.append(
 		    QObject::tr("Message '%1' does not contain acceptance info data necessary for PDF export.")
@@ -708,12 +709,6 @@ void DlgCorrespondenceOverview::exportChosenData(const QString &userName,
 	}
 
 finish:
-	QMessageBox msgBox(this);
-	msgBox.setIcon(QMessageBox::Information);
-	msgBox.setWindowTitle(tr("Export results"));
-	msgBox.setText(
-	    tr("Export of correspondence overview finished with these results:"));
-
 	if (!errorList.isEmpty()) {
 		summaryMsg += QStringLiteral("<br/><b>") +
 		    tr("Some errors occurred during export.") +
@@ -721,17 +716,13 @@ finish:
 		    tr("See detail for more info...") +
 		    QStringLiteral("<br/><br/>");
 	}
-	msgBox.setInformativeText(summaryMsg);
-
-	QString msg;
+	QString detailMsg;
 	if (!errorList.isEmpty()) {
 		for (int i = 0; i < errorList.count(); ++i) {
-			msg += errorList.at(i) + QStringLiteral("\n");
+			detailMsg += errorList.at(i) + QStringLiteral("\n");
 		}
-		msgBox.setDetailedText(msg);
 	}
-
-	msgBox.setStandardButtons(QMessageBox::Ok);
-	msgBox.setDefaultButton(QMessageBox::Ok);
-	msgBox.exec();
+	DlgMsgBox::message(this, QMessageBox::Information, tr("Export results"),
+	    tr("Export of correspondence overview finished with these results:"),
+	    summaryMsg, detailMsg, QMessageBox::Ok, QMessageBox::Ok);
 }
