@@ -25,21 +25,60 @@
 #define _DLG_DS_SEARCH_H_
 
 #include <QDialog>
-#include <QTimer>
+#include <QItemSelection>
+#include <QThread>
 
-#include "src/common.h"
 #include "src/models/combo_box_model.h"
 #include "src/models/data_box_contacts_model.h"
+#include "src/models/sort_filter_proxy_model.h"
 #include "src/worker/task_search_owner.h"
 #include "src/worker/task_search_owner_fulltext.h"
-#include "ui_dlg_ds_search.h"
+
+class DlgDsSearch; /* Forward declaration. */
+
+/*!
+ * @brief Thread performing full-text data box searching.
+ */
+class FulltextSearchThread : public QThread {
+	Q_OBJECT
+
+public:
+	/*!
+	 * @brief Constructor.
+	 */
+	explicit FulltextSearchThread(DlgDsSearch *dlg);
+
+signals:
+	/*!
+	 * @brief Emitted when search finishes.
+	 *
+	 * @param[in] result Task result code.
+	 * @param[in] longErrMsg Long error message.
+	 */
+	void searchFinished(int result, const QString &longErrMsg);
+
+protected:
+	/*!
+	 * @brief Thread function.
+	 */
+	virtual
+	void run(void) Q_DECL_OVERRIDE;
+
+private:
+	DlgDsSearch *m_dlg; /*!< Pointer to data box search window. */
+};
+
+namespace Ui {
+	class DlgDsSearch;
+}
 
 /*!
  * @brief Data box search dialogue.
  */
-class DlgDsSearch : public QDialog, public Ui::DsSearch {
+class DlgDsSearch : public QDialog {
 	Q_OBJECT
-public:
+
+private:
 	/*!
 	 * @brief Constructor.
 	 */
@@ -47,12 +86,23 @@ public:
 	    bool dbEffectiveOVM, bool dbOpenAddressing,
 	    QStringList *dbIdList = Q_NULLPTR, QWidget *parent = Q_NULLPTR);
 
+public:
 	/*!
 	 * @brief Destructor.
 	 */
 	virtual
 	~DlgDsSearch(void);
 
+	/*!
+	 * @brief Show data box search dialogue.
+	 *
+	 * @return List of data-box identifiers.
+	 */
+	static
+	QStringList search(const QString &userName, const QString &dbType,
+	    bool dbEffectiveOVM, bool dbOpenAddressing,
+	    QWidget *parent = Q_NULLPTR);
+
 private slots:
 	/*!
 	 * @brief Activates confirmation button.
@@ -73,6 +123,15 @@ private slots:
 	 */
 	void checkInputFields(void);
 
+	/*!
+	 * @brief Run on search thread exit.
+	 *
+	 * @param[in] result Full-text task result code.
+	 * @param[in] longErrMsg Long error message.
+	 */
+	void collectFulltextThreadOutcome(int result,
+	    const QString &longErrMsg);
+
 	/*!
 	 * @brief Search for data boxes according given criteria.
 	 */
@@ -93,11 +152,6 @@ private slots:
 	 */
 	void setBreakDownloadLoop(void);
 
-	/*!
-	 * @brief Ping the ISDS server, test whether connection is active.
-	 */
-	void pingIsdsServer(void) const;
-
 	/*!
 	 * @brief Displays elements relevant for normal or full-text search.
 	 *
@@ -105,7 +159,49 @@ private slots:
 	 */
 	void makeSearchElelementsVisible(int fulltextState);
 
+	/*!
+	 * @brief Apply filter text on the table.
+	 */
+	void filterContact(const QString &text);
+
 private:
+	/*!
+	 * @brief Normal search result.
+	 */
+	class SearchResult {
+	public:
+		/*!
+		 * @brief Constructor.
+		 */
+		SearchResult(enum TaskSearchOwner::Result r,
+		    const QString &lErr)
+		    : result(r), longErrMsg(lErr)
+		{
+		}
+
+		enum TaskSearchOwner::Result result;
+		QString longErrMsg;
+	};
+
+	/*!
+	 * @brief Full-text search result.
+	 */
+	class SearchResultFt {
+	public:
+		/*!
+		 * @brief Constructor.
+		 */
+		SearchResultFt(enum TaskSearchOwnerFulltext::Result r,
+		    const QString &lErr, bool lp)
+		    : result(r), longErrMsg(lErr), lastPage(lp)
+		{
+		}
+
+		enum TaskSearchOwnerFulltext::Result result;
+		QString longErrMsg;
+		bool lastPage; /*!< True if last page acquired. */
+	};
+
 	/*!
 	 * @brief Initialise dialogue content.
 	 */
@@ -124,12 +220,18 @@ private:
 	/*!
 	 * @brief Normal search for data boxes according given criteria.
 	 */
-	void searchDataBoxNormal(void);
+	SearchResult searchDataBoxNormal(void);
 
 	/*!
 	 * @brief Full-text search for data boxes according given criteria.
 	 */
-	void searchDataBoxFulltext(void);
+	SearchResultFt searchDataBoxFulltext(void);
+
+	/*!
+	 * @brief Full-text search for data boxes according given criteria
+	 *     run in background.
+	 */
+	void searchDataBoxFulltextThread(void);
 
 	/*!
 	 * @brief Encapsulates query.
@@ -139,11 +241,19 @@ private:
 	 * @param[in] ic Identifier number.
 	 * @param[in] name Name to search for.
 	 * @param[in] zipCode ZIP code.
+	 * @return Search result.
 	 */
-	void queryBoxNormal(const QString &boxId,
+	SearchResult queryBoxNormal(const QString &boxId,
 	    enum TaskSearchOwner::BoxType boxType, const QString &ic,
 	    const QString &name, const QString &zipCode);
 
+	/*!
+	 * @brief Display message about search result.
+	 *
+	 * @param[in] searchResult Search task result code.
+	 */
+	void displaySearchResult(const SearchResult &searchResult);
+
 	/*!
 	 * @brief Encapsulates full-text query for a single page.
 	 *
@@ -151,9 +261,9 @@ private:
 	 * @param[in] boxType Type of data box to search for.
 	 * @param[in] phrase Text phrase to search for.
 	 * @param[in] pageNum Page umber to ask for.
-	 * @return False on error or when last page downloaded.
+	 * @return Search result.
 	 */
-	bool queryBoxFulltextPage(
+	SearchResultFt queryBoxFulltextPage(
 	    enum TaskSearchOwnerFulltext::FulltextTarget target,
 	    enum TaskSearchOwnerFulltext::BoxType boxType,
 	    const QString &phrase, qint64 pageNum);
@@ -165,26 +275,53 @@ private:
 	 * @param[in] boxType Type of data box to search for.
 	 * @param[in] phrase Text phrase to search for.
 	 */
-	void queryBoxFulltextAll(
+	SearchResultFt queryBoxFulltextAll(
 	    enum TaskSearchOwnerFulltext::FulltextTarget target,
 	    enum TaskSearchOwnerFulltext::BoxType boxType,
 	    const QString &phrase);
 
+	/*!
+	 * @brief Display message about full-text search result.
+	 *
+	 * @param[in] result Full-text task result code.
+	 * @param[in] longErrMsg Long error message.
+	 */
+	void displaySearchResultFt(int result, const QString &longErrMsg);
+
+	/*!
+	 * @brief Returns total found string.
+	 *
+	 * @param[in] total Total found number.
+	 * @return String containing total found summary.
+	 */
+	static
+	QString totalFoundStr(int total);
+
+	/* Allow access from search thread to dialogue controls. */
+	friend class FulltextSearchThread;
+
+	Ui::DlgDsSearch *m_ui; /*!< UI generated from UI file. */
+
+	FulltextSearchThread m_fulltextThread; /*!< Tread that's waiting for incoming full-text search result. */
+
 	const QString m_userName; /*!< User name used for searching. */
 	const QString m_dbType; /*!< Data box type used for searching.  */
-	const bool m_dbEffectiveOVM;
-	const bool m_dbOpenAddressing;
+	const bool m_dbEffectiveOVM; /*!< True if box has OVM status. */
+	const bool m_dbOpenAddressing; /*!< True if open addressing is enabled. */
 
+	SortFilterProxyModel m_contactListProxyModel; /*!<
+	                                               * Used for message
+	                                               * sorting and filtering.
+	                                               */
 	BoxContactsModel m_contactTableModel; /*!< Model of found data boxes. */
 	CBoxModel m_boxTypeCBoxModel; /*!< Data box type combo box model. */
 	CBoxModel m_fulltextCBoxModel; /*!< Full-text combo box model. */
 
 	QStringList *m_dbIdList; /*!< List of box identifiers to append to. */
 
-	bool m_breakDownloadLoop; /*!< Setting to true interrupts download loop. */
+	volatile bool m_breakDownloadLoop; /*!< Setting to true interrupts download loop. */
 
-	QTimer *m_pingTimer;
-	bool m_showInfoLabel;
+	bool m_showInfoLabel; /*!< Controls the notification about limited search results. */
 };
 
 #endif /* DLG_DS_SEARCH_H */
