@@ -29,7 +29,6 @@
 #include <QDialog>
 
 #include "src/io/message_db_set.h"
-#include "src/models/accounts_model.h"
 #include "ui_dlg_msg_search.h"
 
 
@@ -58,7 +57,7 @@ private:
 	const QString m_userName;
 
 	void initSearchWindow(void);
-	int howManyFieldsAreFill(void);
+	int howManyFieldsAreFilledWithoutTag(void);
 	void appendMsgsToTable(
 	    const QPair<QString, MessageDbSet *> &usrNmAndMsgDbSet,
 	    const QList<MessageDb::SoughtMsg> &msgDataList);
