@@ -31,18 +31,18 @@
 #include "src/gui/dlg_change_pwd.h"
 #include "src/gui/dlg_contacts.h"
 #include "src/gui/dlg_ds_search.h"
-#include "src/gui/dlg_search_mojeid.h"
+#include "src/gui/dlg_msg_box_informative.h"
 #include "src/gui/dlg_send_message.h"
 #include "src/gui/dlg_yes_no_checkbox.h"
 #include "src/model_interaction/attachment_interaction.h"
-#include "src/models/accounts_model.h"
 #include "src/io/account_db.h"
 #include "src/io/dbs.h"
 #include "src/io/isds_sessions.h"
-#include "src/io/wd_sessions.h"
 #include "src/io/message_db.h"
+#include "src/isds/isds_conversion.h"
 #include "src/localisation/localisation.h"
 #include "src/log/log.h"
+#include "src/settings/accounts.h"
 #include "src/settings/preferences.h"
 #include "src/views/attachment_table_view.h"
 #include "src/views/table_home_end_filter.h"
@@ -53,26 +53,25 @@
 #include "src/worker/task_send_message.h"
 #include "src/worker/task_search_owner.h"
 #include "src/worker/task_search_owner_fulltext.h"
-#include "src/worker/task_send_message_mojeid.h"
 #include "src/worker/task_search_owner.h"
 #include "ui_dlg_send_message.h"
 
 /*
- * Message types as defined in ISDS alnd used in libisds.
- * For details see linisds.h .
+ * Message types as defined in ISDS and used in libisds.
+ * For details see libisds.h .
  */
 #define DMTYPE_INIT "I"
 #define DMTYPE_COMM "K"
 #define DMTYPE_RESP "O"
 
-const QString &dzPrefix(MessageDb *messageDb, qint64 dmId)
+const QString &dzPrefix(const MessageDb *messageDb, qint64 dmId)
 {
-	const static QString nothing;
-	const static QString received(QLatin1String("D"));
-	const static QString sent(QLatin1String("O"));
+	const static QString unspecified(QLatin1String("DZ"));
+	const static QString received(QLatin1String("DDZ"));
+	const static QString sent(QLatin1String("ODZ"));
 
-	if (Q_NULLPTR == messageDb || dmId < 0) {
-		return nothing;
+	if (Q_UNLIKELY(Q_NULLPTR == messageDb || dmId < 0)) {
+		return unspecified;
 	}
 
 	switch (messageDb->msgMessageType(dmId)) {
@@ -83,7 +82,7 @@ const QString &dzPrefix(MessageDb *messageDb, qint64 dmId)
 		return sent;
 		break;
 	default:
-		return nothing;
+		return unspecified;
 		break;
 	}
 }
@@ -102,7 +101,6 @@ DlgSendMessage::DlgSendMessage(
     m_dbEffectiveOVM(false),
     m_dbOpenAddressing(false),
     m_isLogged(false),
-    m_isWebDatovkaAccount(false),
     m_lastAttAddPath(),
     m_pdzCredit("0"),
     m_dmType(),
@@ -163,22 +161,8 @@ void DlgSendMessage::addRecipientFromLocalContact(void)
 
 void DlgSendMessage::addRecipientFromISDSSearch(void)
 {
-	QStringList dbIDs;
-	QDialog *dsSearch = Q_NULLPTR;
-	if (!m_isWebDatovkaAccount) {
-		dsSearch = new DlgDsSearch(m_userName, m_dbType,
-		    m_dbEffectiveOVM, m_dbOpenAddressing, &dbIDs, this);
-	} else {
-#if 0 /* TODO -- MojeID functionality disabled, deal with it later. */
-		dsSearch = new DlgDsSearchMojeId(DlgDsSearchMojeId::ACT_ADDNEW,
-		    this->recipientTableWidget, m_dbType, m_dbEffectiveOVM,
-		    this, m_userName);
-#else
-		return;
-#endif
-	}
-	dsSearch->exec();
-	dsSearch->deleteLater();
+	QStringList dbIDs(DlgDsSearch::search(m_userName, m_dbType,
+	    m_dbEffectiveOVM, m_dbOpenAddressing, this));
 	addRecipientBoxes(dbIDs);
 }
 
@@ -188,20 +172,16 @@ void DlgSendMessage::addRecipientManually(void)
 
 	QString dbID = QInputDialog::getText(this, tr("Databox ID"),
 	    tr("Enter Databox ID (7 characters):"), QLineEdit::Normal,
-	    NULL, &ok, Qt::WindowStaysOnTopHint);
+	    QString(), &ok, Qt::WindowStaysOnTopHint);
 
 	if (!ok) {
 		return;
 	}
 
 	if (dbID.isEmpty() || dbID.length() != 7) {
-		QMessageBox msgBox;
-		msgBox.setIcon(QMessageBox::Critical);
-		msgBox.setWindowTitle(tr("Wrong data box ID"));
-		msgBox.setText(tr("Wrong data box ID '%1'!").arg(dbID));
-		msgBox.setStandardButtons(QMessageBox::Ok);
-		msgBox.setDefaultButton(QMessageBox::Ok);
-		msgBox.exec();
+		QMessageBox::critical(this, tr("Wrong data box ID"),
+		    tr("Wrong data box ID '%1'!").arg(dbID),
+		    QMessageBox::Ok, QMessageBox::Ok);
 		return;
 	}
 
@@ -243,7 +223,7 @@ public:
 static
 void removeSelectedEntries(const QTableView *view, QAbstractItemModel *model)
 {
-	if ((view == Q_NULLPTR) || (model == Q_NULLPTR)) {
+	if (Q_UNLIKELY((view == Q_NULLPTR) || (model == Q_NULLPTR))) {
 		Q_ASSERT(0);
 		return;
 	}
@@ -372,43 +352,30 @@ void DlgSendMessage::setAccountInfo(int fromComboIdx)
 		m_userName = userName;
 	}
 
-	if (isWebDatovkaAccount(m_userName)) {
-		m_isWebDatovkaAccount = true;
+
+	m_isLogged = true;
+	m_keepAliveTimer.stop();
+	{
+		TaskKeepAlive *task =
+		    new (std::nothrow) TaskKeepAlive(m_userName);
+		task->setAutoDelete(false);
+		globWorkPool.runSingle(task);
+
+		m_isLogged = task->m_isAlive;
+
+		delete task;
 	}
-
-	if (!m_isWebDatovkaAccount) {
-
-		m_isLogged = true;
-		m_keepAliveTimer.stop();
-		{
-			TaskKeepAlive *task =
-			    new (std::nothrow) TaskKeepAlive(m_userName);
-			task->setAutoDelete(false);
-			globWorkPool.runSingle(task);
-
-			m_isLogged = task->m_isAlive;
-
-			delete task;
+	if (!m_isLogged) {
+		if (Q_NULLPTR != m_mw) {
+			m_isLogged = m_mw->connectToIsds(m_userName);
 		}
-		if (!m_isLogged) {
-			if (Q_NULLPTR != m_mw) {
-				m_isLogged = m_mw->connectToIsds(m_userName);
-			}
-		}
-		m_keepAliveTimer.start(DLG_ISDS_KEEPALIVE_MS);
+	}
+	m_keepAliveTimer.start(DLG_ISDS_KEEPALIVE_MS);
 
-		/* Check for presence of struct isds_ctx . */
-		if (NULL == globIsdsSessions.session(m_userName)) {
-			logErrorNL("%s", "Missing ISDS session.");
-			m_isLogged = false;
-		}
-	} else {
-		if (!wdSessions.isConnectedToWebdatovka(m_userName)) {
-			if (Q_NULLPTR != m_mw) {
-				m_mw->loginToMojeId(m_userName);
-			}
-		}
-		m_isLogged = true;
+	/* Check for presence of struct isds_ctx . */
+	if (NULL == globIsdsSessions.session(m_userName)) {
+		logErrorNL("%s", "Missing ISDS session.");
+		m_isLogged = false;
 	}
 
 	foreach (const Task::AccountDescr &acnt, m_messageDbSetList) {
@@ -418,7 +385,7 @@ void DlgSendMessage::setAccountInfo(int fromComboIdx)
 		}
 	}
 
-	const AcntSettings &accountInfo(AccountModel::globAccounts[m_userName]);
+	const AcntSettings &accountInfo(globAccounts[m_userName]);
 	const QString acntDbKey(AccountDb::keyFromLogin(m_userName));
 	m_dbId = globAccountDbPtr->dbId(acntDbKey);
 	Q_ASSERT(!m_dbId.isEmpty());
@@ -436,10 +403,8 @@ void DlgSendMessage::setAccountInfo(int fromComboIdx)
 		m_lastAttAddPath = accountInfo.lastAttachAddPath();
 	}
 
-	if (!m_isWebDatovkaAccount) {
-		if (m_dbOpenAddressing) {
-			m_pdzCredit = getPDZCreditFromISDS(m_userName, m_dbId);
-		}
+	if (m_dbOpenAddressing) {
+		m_pdzCredit = getPDZCreditFromISDS(m_userName, m_dbId);
 	}
 
 	QString dbOpenAddressingText;
@@ -455,9 +420,8 @@ void DlgSendMessage::setAccountInfo(int fromComboIdx)
 	}
 
 	this->fromUser->setText("<strong>" +
-	    AccountModel::globAccounts[m_userName].accountName() +
-	    "</strong>" + " (" + m_userName + ") - " + m_dbType +
-	    dbOpenAddressingText);
+	    globAccounts[m_userName].accountName() + "</strong>" +
+	    " (" + m_userName + ") - " + m_dbType + dbOpenAddressingText);
 }
 
 void DlgSendMessage::sendMessage(void)
@@ -467,11 +431,8 @@ void DlgSendMessage::sendMessage(void)
 	const QList<BoxContactsModel::PartialEntry> recipEntries(
 	    m_recipientTableModel.partialBoxEntries(BoxContactsModel::ANY));
 
-	if (!m_isWebDatovkaAccount) {
-		sendMessageISDS(recipEntries);
-	} else {
-		sendMessageWebDatovka(recipEntries);
-	}
+
+	sendMessageISDS(recipEntries);
 }
 
 void DlgSendMessage::collectSendMessageStatus(const QString &userName,
@@ -509,7 +470,7 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 	this->setEnabled(true);
 
 	int successfullySentCnt = 0;
-	QString detailText;
+	QString infoText;
 
 	foreach (const TaskSendMessage::ResultData &resultData,
 	         m_sentMsgResultList) {
@@ -517,7 +478,7 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 			++successfullySentCnt;
 
 			if (resultData.isPDZ) {
-				detailText += tr(
+				infoText += tr(
 				    "Message was successfully sent to "
 				    "<i>%1 (%2)</i> as PDZ with number "
 				    "<i>%3</i>.").
@@ -525,7 +486,7 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 				    arg(resultData.dbIDRecipient).
 				    arg(resultData.dmId) + "<br/>";
 			} else {
-				detailText += tr(
+				infoText += tr(
 				    "Message was successfully sent to "
 				    "<i>%1 (%2)</i> as message number "
 				    "<i>%3</i>.").
@@ -534,7 +495,7 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 				    arg(resultData.dmId) + "<br/>";
 			}
 		} else {
-			detailText += tr("Message was NOT sent to "
+			infoText += tr("Message was NOT sent to "
 			    "<i>%1 (%2)</i>. Server says: %3").
 			    arg(resultData.recipientName).
 			    arg(resultData.dbIDRecipient).
@@ -544,29 +505,20 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 	m_sentMsgResultList.clear();
 
 	if (m_recipientTableModel.rowCount() == successfullySentCnt) {
-		QMessageBox msgBox;
-		msgBox.setIcon(QMessageBox::Information);
-		msgBox.setWindowTitle(tr("Message sent"));
-		msgBox.setText("<b>" +
-		    tr("Message was successfully sent to all recipients.") +
-		    "</b>");
-		msgBox.setInformativeText(detailText);
-		msgBox.setStandardButtons(QMessageBox::Ok);
-		msgBox.setDefaultButton(QMessageBox::Ok);
-		msgBox.exec();
+		DlgMsgBox::message(this, QMessageBox::Information,
+		    tr("Message sent"),
+		    "<b>" + tr("Message was successfully sent to all recipients.") + "</b>",
+		    infoText, QString(), QMessageBox::Ok, QMessageBox::Ok);
 		this->accept(); /* Set return code to accepted. */
 	} else {
-		QMessageBox msgBox;
-		msgBox.setIcon(QMessageBox::Warning);
-		msgBox.setWindowTitle(tr("Message sending error"));
-		msgBox.setText("<b>" +
-		    tr("Message was NOT sent to all recipients.") + "</b>");
-		detailText += "<br/><br/><b>" +
+		infoText += "<br/><br/><b>" +
 		    tr("Do you want to close the Send message form?") + "</b>";
-		msgBox.setInformativeText(detailText);
-		msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-		msgBox.setDefaultButton(QMessageBox::No);
-		if (msgBox.exec() == QMessageBox::Yes) {
+		int ret = DlgMsgBox::message(this, QMessageBox::Warning,
+		    tr("Message sending error"),
+		    "<b>" + tr("Message was NOT sent to all recipients.") + "</b>",
+		    infoText, QString(), QMessageBox::Yes | QMessageBox::No,
+		    QMessageBox::No);
+		if (ret == QMessageBox::Yes) {
 			this->close(); /* Set return code to closed. */
 		}
 	}
@@ -574,56 +526,9 @@ void DlgSendMessage::collectSendMessageStatus(const QString &userName,
 	emit usedAttachmentPath(m_userName, m_lastAttAddPath);
 }
 
-void DlgSendMessage::collectSendMessageStatusWebDatovka(const QString &userName,
-    const QStringList &results, const QString &error)
-{
-	debugSlotCall();
-
-	Q_UNUSED(error);
-
-	QString detailText;
-
-	if (results.isEmpty()) {
-		QMessageBox msgBox;
-		msgBox.setIcon(QMessageBox::Information);
-		msgBox.setWindowTitle(tr("Message sent"));
-		msgBox.setText("<b>" +
-		    tr("Message was successfully sent to all recipients.") +
-		    "</b>");
-		msgBox.setStandardButtons(QMessageBox::Ok);
-		msgBox.setDefaultButton(QMessageBox::Ok);
-		msgBox.exec();
-		this->accept(); /* Set return code to accepted. */
-		emit usedAttachmentPath(userName, m_lastAttAddPath);
-	} else {
-		for (int i = 0; i < results.count(); ++i) {
-			QString msg = results.at(i);
-			detailText += msg.replace("§", ": ");
-		}
-		QMessageBox msgBox;
-		msgBox.setIcon(QMessageBox::Warning);
-		msgBox.setWindowTitle(tr("Message sending error"));
-		msgBox.setText("<b>" +
-		    tr("Message was NOT sent to all recipients.") + "</b>");
-		detailText += "<br/><br/><b>" +
-		    tr("Do you want to close the Send message form?") + "</b>";
-		msgBox.setInformativeText(detailText);
-		msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-		msgBox.setDefaultButton(QMessageBox::No);
-		if (msgBox.exec() == QMessageBox::Yes) {
-			this->close(); /* Set return code to closed. */
-			emit usedAttachmentPath(userName, m_lastAttAddPath);
-		}
-	}
-}
-
 void DlgSendMessage::initContent(enum Action action,
     const QList<MessageDb::MsgId> &msgIds)
 {
-	if (isWebDatovkaAccount(m_userName)) {
-		m_isWebDatovkaAccount = true;
-	}
-
 	m_recipientTableModel.setHeader();
 	this->recipientTableView->setModel(&m_recipientTableModel);
 
@@ -660,7 +565,7 @@ void DlgSendMessage::initContent(enum Action action,
 
 	foreach (const Task::AccountDescr &acnt, m_messageDbSetList) {
 		const QString accountName =
-		    AccountModel::globAccounts[acnt.userName].accountName() +
+		    globAccounts[acnt.userName].accountName() +
 		    " (" + acnt.userName + ")";
 		this->fromComboBox->addItem(accountName, QVariant(acnt.userName));
 		if (m_userName == acnt.userName) {
@@ -744,23 +649,15 @@ void DlgSendMessage::initContent(enum Action action,
 	        QString, QString, bool, qint64)), this,
 	    SLOT(collectSendMessageStatus(QString, QString, int, QString,
 	        QString, QString, bool, qint64)));
-	connect(&globMsgProcEmitter,
-	    SIGNAL(sendMessageMojeIdFinished(QString, QStringList, QString)),
-	    this,
-	    SLOT(collectSendMessageStatusWebDatovka(QString, QStringList,
-	        QString)));
 
 	m_keepAliveTimer.start(DLG_ISDS_KEEPALIVE_MS);
 
-	if (!m_isWebDatovkaAccount) {
-		connect(&m_keepAliveTimer, SIGNAL(timeout()), this,
-		    SLOT(pingIsdsServer()));
-	}
+	connect(&m_keepAliveTimer, SIGNAL(timeout()), this, SLOT(pingIsdsServer()));
 
 	this->attachmentSizeInfo->setText(
 	    tr("Total size of attachments is %1 B").arg(0));
 
-	if (convertDbTypeToInt(m_dbType) > DBTYPE_OVM_REQ) {
+	if (IsdsConversion::boxTypeStrToInt(m_dbType) > DBTYPE_OVM_REQ) {
 		this->dmAllowSubstDelivery->setEnabled(false);
 		this->dmAllowSubstDelivery->hide();
 	}
@@ -821,7 +718,7 @@ void DlgSendMessage::fillContentAsForward(const QList<MessageDb::MsgId> &msgIds)
 		}
 
 		m_attachmentModel.appendAttachmentEntry(msgBase64,
-		    dzPrefix(messageDb, msgId.dmId) + QString("DZ_%1.zfo").arg(msgId.dmId));
+		    QString("%1_%2.zfo").arg(dzPrefix(messageDb, msgId.dmId)).arg(msgId.dmId));
 	}
 }
 
@@ -1005,7 +902,7 @@ void DlgSendMessage::fillContentFromTemplate(
 	}
 }
 
-int DlgSendMessage::notifyOfPDZ(int pdzCnt) const
+int DlgSendMessage::notifyOfPDZ(int pdzCnt)
 {
 	QString title;
 	QString info;
@@ -1029,13 +926,9 @@ int DlgSendMessage::notifyOfPDZ(int pdzCnt) const
 
 	info += "\n\n" + tr("Your remaining credit is ") + m_pdzCredit + " Kč";
 
-	QMessageBox msgBox;
-	msgBox.setIcon(QMessageBox::Information);
-	msgBox.setText(title);
-	msgBox.setInformativeText(info);
-	msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-	msgBox.setDefaultButton(QMessageBox::Yes);
-	return msgBox.exec();
+	return DlgMsgBox::message(this, QMessageBox::Information, title, title,
+	    info, QString(), QMessageBox::Yes | QMessageBox::No,
+	    QMessageBox::Yes);
 }
 
 bool DlgSendMessage::calculateAndShowTotalAttachSize(void)
@@ -1123,17 +1016,12 @@ void DlgSendMessage::addRecipientBox(const QString &boxId)
 		address = entry.address;
 		boxType = entry.type;
 		if (!entry.active) {
-			QMessageBox msgBox;
-			msgBox.setIcon(QMessageBox::Warning);
-			msgBox.setWindowTitle(tr("Data box is not active"));
-			msgBox.setText(tr(
-			    "Recipient with data box ID '%1' does not have active data box.")
-			    .arg(boxId));
-			msgBox.setInformativeText(
-			    tr("The message cannot be delivered."));
-			msgBox.setStandardButtons(QMessageBox::Ok);
-			msgBox.setDefaultButton(QMessageBox::Ok);
-			msgBox.exec();
+			DlgMsgBox::message(this, QMessageBox::Warning,
+			    tr("Data box is not active"),
+			    tr("Recipient with data box ID '%1' does not have active data box.")
+			        .arg(boxId),
+			    tr("The message cannot be delivered."), QString(),
+			    QMessageBox::Ok, QMessageBox::Ok);
 			return;
 		}
 		if (entry.publicSending) {
@@ -1143,32 +1031,22 @@ void DlgSendMessage::addRecipientBox(const QString &boxId)
 		} else if (entry.effectiveOVM) {
 			pdz = false;
 		} else {
-			QMessageBox msgBox;
-			msgBox.setIcon(QMessageBox::Critical);
-			msgBox.setWindowTitle(tr("Cannot send to data box"));
-			msgBox.setText(tr(
-			    "Cannot send message to recipient with data box ID '%1'.")
-			    .arg(boxId));
-			msgBox.setInformativeText(tr(
-			    "You won't be able as user '%1' to send messages into data box '%2'.")
-			    .arg(m_userName).arg(boxId));
-			msgBox.setStandardButtons(QMessageBox::Ok);
-			msgBox.setDefaultButton(QMessageBox::Ok);
-			msgBox.exec();
+			DlgMsgBox::message(this, QMessageBox::Critical,
+			    tr("Cannot send to data box"),
+			    tr("Cannot send message to recipient with data box ID '%1'.")
+			        .arg(boxId),
+			    tr("You won't be able as user '%1' to send messages into data box '%2'.")
+			        .arg(m_userName).arg(boxId),
+			    QString(), QMessageBox::Ok, QMessageBox::Ok);
 			return;
 		}
 	} else if (foundBoxes.isEmpty()) {
 		if (result == TaskSearchOwnerFulltext::SOF_SUCCESS) {
 			/* No data box found. */
-			QMessageBox msgBox;
-			msgBox.setIcon(QMessageBox::Critical);
-			msgBox.setWindowTitle(tr("Wrong Recipient"));
-			msgBox.setText(tr(
-			    "Recipient with data box ID '%1' does not exist.")
-			    .arg(boxId));
-			msgBox.setStandardButtons(QMessageBox::Ok);
-			msgBox.setDefaultButton(QMessageBox::Ok);
-			msgBox.exec();
+			QMessageBox::critical(this, tr("Wrong Recipient"),
+			    tr("Recipient with data box ID '%1' does not exist.")
+			        .arg(boxId),
+			    QMessageBox::Ok, QMessageBox::Ok);
 			return;
 		} else {
 			/* Search error. */
@@ -1200,7 +1078,6 @@ void DlgSendMessage::addRecipientBox(const QString &boxId)
 
 	m_recipientTableModel.appendData(boxId, boxType, name, address,
 	    QString(), pdz);
-
 }
 
 void DlgSendMessage::addRecipientBoxes(const QStringList &boxIds)
@@ -1288,7 +1165,7 @@ bool DlgSendMessage::buildEnvelope(IsdsEnvelope &envelope) const
 	envelope.dmPersonalDelivery = this->dmPersonalDelivery->isChecked();
 
 	/* Only OVM can change. */
-	if (convertDbTypeToInt(m_dbType) > DBTYPE_OVM_REQ) {
+	if (IsdsConversion::boxTypeStrToInt(m_dbType) > DBTYPE_OVM_REQ) {
 		envelope.dmAllowSubstDelivery = true;
 	} else {
 		envelope.dmAllowSubstDelivery =
@@ -1366,7 +1243,7 @@ bool DlgSendMessage::buildDocuments(QList<IsdsDocument> &documents) const
 void DlgSendMessage::sendMessageISDS(
     const QList<BoxContactsModel::PartialEntry> &recipEntries)
 {
-	QString detailText;
+	QString infoText;
 
 	/* List of unique identifiers. */
 	QList<QString> taskIdentifiers;
@@ -1399,11 +1276,11 @@ void DlgSendMessage::sendMessageISDS(
 
 	/* Attach envelope and attachment files to message structure. */
 	if (!buildDocuments(message.documents)) {
-		detailText = tr("An error occurred while loading attachments into message.");
+		infoText = tr("An error occurred while loading attachments into message.");
 		goto finish;
 	}
 	if (!buildEnvelope(message.envelope)) {
-		detailText = tr("An error occurred during message envelope creation.");
+		infoText = tr("An error occurred during message envelope creation.");
 		goto finish;
 	}
 
@@ -1443,98 +1320,9 @@ void DlgSendMessage::sendMessageISDS(
 	return;
 
 finish:
-	QMessageBox msgBox;
-	msgBox.setIcon(QMessageBox::Critical);
-	msgBox.setWindowTitle(tr("Send message error"));
-	msgBox.setText(tr("It has not been possible to send a message to the ISDS server."));
-	detailText += "\n\n" + tr("The message will be discarded.");
-	msgBox.setInformativeText(detailText);
-	msgBox.setStandardButtons(QMessageBox::Ok);
-	msgBox.exec();
+	infoText += "\n\n" + tr("The message will be discarded.");
+	DlgMsgBox::message(this, QMessageBox::Critical, tr("Send message error"),
+	    tr("It has not been possible to send a message to the ISDS server."),
+	    infoText, QString(), QMessageBox::Ok);
 	this->close();
 }
-
-void DlgSendMessage::buildEnvelopeWebDatovka(
-    JsonLayer::Envelope &envelope) const
-{
-	/* Set mandatory fields of envelope. */
-	envelope.dmAnnotation = this->subjectText->text();
-
-	/* Set optional fields. */
-	envelope.dmSenderIdent = this->dmSenderIdent->text();
-	envelope.dmRecipientIdent = this->dmRecipientIdent->text();
-	envelope.dmSenderRefNumber = this->dmSenderRefNumber->text();
-	envelope.dmRecipientRefNumber = this->dmRecipientRefNumber->text();
-	envelope.dmLegalTitleLaw = this->dmLegalTitleLaw->text();
-	envelope.dmLegalTitleYear = this->dmLegalTitleYear->text();
-	envelope.dmLegalTitleSect = this->dmLegalTitleSect->text();
-	envelope.dmLegalTitlePar = this->dmLegalTitlePar->text();
-	envelope.dmLegalTitlePoint = this->dmLegalTitlePoint->text();
-	envelope.dmPersonalDelivery = this->dmPersonalDelivery->isChecked();
-	envelope.dmPublishOwnID = this->dmPublishOwnID->isChecked();
-	envelope.dmOVM = m_dbEffectiveOVM;
-
-	/* Only OVM can change. */
-	if (convertDbTypeToInt(m_dbType) > DBTYPE_OVM_REQ) {
-		envelope.dmAllowSubstDelivery = true;
-	} else {
-		envelope.dmAllowSubstDelivery =
-		    this->dmAllowSubstDelivery->isChecked();
-	}
-}
-
-void DlgSendMessage::buildFileListWebDatovka(
-    QList<JsonLayer::File> &fileList) const
-{
-	QModelIndex index;
-
-	for (int row = 0; row < m_attachmentModel.rowCount(); ++row) {
-
-		index = m_attachmentModel.index(row, DbFlsTblModel::FNAME_COL);
-		if (!index.isValid()) {
-			Q_ASSERT(0);
-			continue;
-		}
-
-		JsonLayer::File file;
-		file.fName = index.data(Qt::DisplayRole).toString();
-
-		index =
-		    m_attachmentModel.index(row, DbFlsTblModel::CONTENT_COL);
-		if (!index.isValid()) {
-			Q_ASSERT(0);
-			continue;
-		}
-
-		file.fContent = index.data(Qt::DisplayRole).toByteArray();
-		fileList.append(file);
-	}
-}
-
-void DlgSendMessage::sendMessageWebDatovka(
-    const QList<BoxContactsModel::PartialEntry> &recipEntries)
-{
-	/* Get account ID */
-	int accountID = getWebDatovkaAccountId(m_userName);
-
-	/* Create recipient list. */
-	JsonLayer::Recipient recipient;
-	QList<JsonLayer::Recipient> recipientList;
-	foreach (const BoxContactsModel::PartialEntry &e, recipEntries) {
-		recipient.recipientDbId = e.id;
-		recipient.toHands = this->dmToHands->text();
-		recipient.recipientName = e.name;
-		recipient.recipientAddress = e.address;
-		recipientList.append(recipient);
-	}
-
-	JsonLayer::Envelope envelope;
-	buildEnvelopeWebDatovka(envelope);
-	QList<JsonLayer::File> fileList;
-	buildFileListWebDatovka(fileList);
-
-	TaskSendMessageMojeId *task = new (std::nothrow) TaskSendMessageMojeId(
-	    m_userName, accountID, recipientList, envelope, fileList);
-	task->setAutoDelete(true);
-	globWorkPool.assignHi(task);
-}
