@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include "src/io/dbs.h"
 #include "src/io/filesystem.h"
 #include "src/io/isds_sessions.h"
+#include "src/isds/isds_conversion.h"
 #include "src/log/log.h"
 #include "src/model_interaction/attachment_interaction.h"
 #include "src/settings/preferences.h"
@@ -175,11 +176,11 @@ void DlgViewZfo::parseZfoData(const QByteArray &zfoData)
 		goto fail;
 	}
 
-	m_zfoType = ImportZFODialog::IMPORT_MESSAGE_ZFO;
+	m_zfoType = Imports::IMPORT_MESSAGE;
 	Q_ASSERT(NULL == m_message);
 	m_message = loadZfoData(dummy_session, zfoData, m_zfoType);
 	if (NULL == m_message) {
-		m_zfoType = ImportZFODialog::IMPORT_DELIVERY_ZFO;
+		m_zfoType = Imports::IMPORT_DELIVERY;
 		m_message = loadZfoData(dummy_session, zfoData, m_zfoType);
 		if (NULL == m_message) {
 			logError("%s\n", "Cannot parse message data.");
@@ -202,11 +203,11 @@ void DlgViewZfo::parseZfoFile(const QString &zfoFileName)
 		goto fail;
 	}
 
-	m_zfoType = ImportZFODialog::IMPORT_MESSAGE_ZFO;
+	m_zfoType = Imports::IMPORT_MESSAGE;
 	Q_ASSERT(NULL == m_message);
 	m_message = loadZfoFile(dummy_session, zfoFileName, m_zfoType);
 	if (NULL == m_message) {
-		m_zfoType = ImportZFODialog::IMPORT_DELIVERY_ZFO;
+		m_zfoType = Imports::IMPORT_DELIVERY;
 		m_message = loadZfoFile(dummy_session, zfoFileName, m_zfoType);
 		if (NULL == m_message) {
 			logError("Cannot parse file '%s'.\n",
@@ -225,7 +226,7 @@ void DlgViewZfo::setUpDialogue(void)
 {
 	/* TODO -- Adjust splitter sizes. */
 
-	if (ImportZFODialog::IMPORT_DELIVERY_ZFO == m_zfoType) {
+	if (Imports::IMPORT_DELIVERY == m_zfoType) {
 		this->attachmentTable->hide();
 		envelopeTextEdit->setHtml(
 		    deliveryDescriptionHtml(
@@ -323,16 +324,16 @@ QString DlgViewZfo::deliveryDescriptionHtml(const void *msgDER,
 
 	envelopeHeaderDescriptionHtml(html, envelope);
 
-	html += strongAccountInfoLine(tr("Events"),"");
+	html += strongAccountInfoLine(tr("Events"), QString());
 
 	html += indentDivStart;
 	const struct isds_list *event = envelope->events;
 	while (NULL != event) {
 		isds_event *item = (isds_event *) event->data;
 		html += strongAccountInfoLine(
-		        dateTimeStrFromDbFormat(timevalToDbFormat(item->time),
+		    dateTimeStrFromDbFormat(timevalToDbFormat(item->time),
 		        dateTimeDisplayFormat),
-		        item->description);
+		    QString(item->description));
 		event = event->next;
 	}
 	html += divEnd;
@@ -354,24 +355,24 @@ bool DlgViewZfo::envelopeHeaderDescriptionHtml(QString &html,
 
 	html += "<h3>" + tr("Identification") + "</h3>";
 
-	html += strongAccountInfoLine(tr("ID"), envelope->dmID);
-	html += strongAccountInfoLine(tr("Subject"), envelope->dmAnnotation);
-	html += strongAccountInfoLine(tr("Message type"), envelope->dmType);
+	html += strongAccountInfoLine(tr("ID"), QString(envelope->dmID));
+	html += strongAccountInfoLine(tr("Subject"), QString(envelope->dmAnnotation));
+	html += strongAccountInfoLine(tr("Message type"), QString(envelope->dmType));
 
 	html += "<br/>";
 
 	/* Information about message author. */
-	html += strongAccountInfoLine(tr("Sender"), envelope->dmSender);
-	html += strongAccountInfoLine(tr("Sender Databox ID"), envelope->dbIDSender);
+	html += strongAccountInfoLine(tr("Sender"), QString(envelope->dmSender));
+	html += strongAccountInfoLine(tr("Sender Databox ID"), QString(envelope->dbIDSender));
 	html += strongAccountInfoLine(tr("Sender Address"),
-	    envelope->dmSenderAddress);
+	    QString(envelope->dmSenderAddress));
 
 	html += "<br/>";
 
-	html += strongAccountInfoLine(tr("Recipient"), envelope->dmRecipient);
-	html += strongAccountInfoLine(tr("Recipient Databox ID"), envelope->dbIDRecipient);
+	html += strongAccountInfoLine(tr("Recipient"), QString(envelope->dmRecipient));
+	html += strongAccountInfoLine(tr("Recipient Databox ID"), QString(envelope->dbIDRecipient));
 	html += strongAccountInfoLine(tr("Recipient Address"),
-	    envelope->dmRecipientAddress);
+	    QString(envelope->dmRecipientAddress));
 
 	html += "<h3>" + tr("Status") + "</h3>";
 
@@ -389,9 +390,10 @@ bool DlgViewZfo::envelopeHeaderDescriptionHtml(QString &html,
 	QString statusString;
 	if (NULL != envelope->dmMessageStatus) {
 		statusString =
-		    QString::number(convertHexToDecIndex(*(envelope->dmMessageStatus))) +
+		    QString::number(IsdsConversion::msgStatusIsdsToDbRepr(*(envelope->dmMessageStatus))) +
 		    " -- " +
-		    msgStatusToText(convertHexToDecIndex(*(envelope->dmMessageStatus)));
+		    IsdsConversion::msgStatusDbToText(
+		        IsdsConversion::msgStatusIsdsToDbRepr(*(envelope->dmMessageStatus)));
 	}
 	html += strongAccountInfoLine(tr("Status"), statusString);
 
