@@ -29,6 +29,30 @@
 
 #include "src/io/db_tables.h"
 
+void localiseTableDescriptions(void)
+{
+	accntinfTbl.reloadLocalisedDescription();
+	userinfTbl.reloadLocalisedDescription();
+	pwdexpdtTbl.reloadLocalisedDescription();
+
+	msgsTbl.reloadLocalisedDescription();
+	flsTbl.reloadLocalisedDescription();
+	hshsTbl.reloadLocalisedDescription();
+	evntsTbl.reloadLocalisedDescription();
+	prcstTbl.reloadLocalisedDescription();
+	rwmsgdtTbl.reloadLocalisedDescription();
+	rwdlvrinfdtTbl.reloadLocalisedDescription();
+	smsgdtTbl.reloadLocalisedDescription();
+	crtdtTbl.reloadLocalisedDescription();
+	msgcrtdtTbl.reloadLocalisedDescription();
+
+	tagTbl.reloadLocalisedDescription();
+	msgtagsTbl.reloadLocalisedDescription();
+
+	srvcInfTbl.reloadLocalisedDescription();
+	strdFlsMsgsTbl.reloadLocalisedDescription();
+}
+
 
 namespace AccntinfTbl {
 	const QString tabName("account_info");
@@ -680,3 +704,69 @@ namespace MsgTagsTbl {
 SQLiteTbl msgtagsTbl(MsgTagsTbl::tabName, MsgTagsTbl::knownAttrs,
     MsgTagsTbl::attrProps, MsgTagsTbl::colConstraints,
     MsgTagsTbl::tblConstraint);
+
+namespace SrvcInfTbl {
+	const QString tabName("service_info");
+
+	const QVector< QPair<QString, enum EntryType> > knownAttrs = {
+	{"url", DB_TEXT}, /* NOT NULL */
+	{"name", DB_TEXT},
+	{"token_name", DB_TEXT},
+	{"logo_svg", DB_TEXT}
+	/*
+	 *  PRIMARY KEY (url)
+	 */
+	};
+
+	const QMap<QString, QString> colConstraints = {
+	    {"url", "NOT NULL"}
+	};
+
+	const QString tblConstraint(
+	    ",\n"
+	    "        PRIMARY KEY (url)"
+	);
+
+	const QMap<QString, SQLiteTbl::AttrProp> attrProps = {
+	{"url",        {DB_TEXT, ""}},
+	{"name",       {DB_TEXT, ""}},
+	{"token_name", {DB_TEXT, ""}},
+	{"logo_svg",   {DB_TEXT, ""}}
+	};
+} /* namespace SrvcInfTbl */
+SQLiteTbl srvcInfTbl(SrvcInfTbl::tabName, SrvcInfTbl::knownAttrs,
+    SrvcInfTbl::attrProps, SrvcInfTbl::colConstraints,
+    SrvcInfTbl::tblConstraint);
+
+namespace StrdFlsMsgsTbls {
+	const QString tabName("stored_files_messages");
+
+	const QVector< QPair<QString, enum EntryType> > knownAttrs = {
+	{"dm_id", DB_INTEGER}, /* NOT NULL */
+	{"separator", DB_TEXT}, /* NOT NULL */
+	{"joined_locations", DB_TEXT} /* NOT NULL */
+	/*
+	 *  PRIMARY KEY (dm_id)
+	 */
+	};
+
+	const QMap<QString, QString> colConstraints = {
+	    {"dm_id", "NOT NULL"},
+	    {"separator", "NOT NULL"},
+	    {"joined_locations", "NOT NULL"}
+	};
+
+	const QString tblConstraint(
+	    ",\n"
+	    "        PRIMARY KEY (dm_id)"
+	);
+
+	const QMap<QString, SQLiteTbl::AttrProp> attrProps = {
+	{"dm_id",            {DB_INTEGER, ""}},
+	{"separator",        {DB_TEXT, ""}},
+	{"joined_locations", {DB_TEXT, ""}}
+	};
+} /* namespace StrdFlsMsgsTbls */
+SQLiteTbl strdFlsMsgsTbl(StrdFlsMsgsTbls::tabName, StrdFlsMsgsTbls::knownAttrs,
+    StrdFlsMsgsTbls::attrProps, StrdFlsMsgsTbls::colConstraints,
+    StrdFlsMsgsTbls::tblConstraint);
