@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,11 @@
 
 #include "src/io/sqlite/table.h"
 
+/*!
+ * @brief Localised table descriptions.
+ */
+void localiseTableDescriptions(void);
+
 /*
  * Account database.
  */
@@ -53,4 +58,10 @@ extern SQLiteTbl msgcrtdtTbl; /*!< Table 'message_certificate_data'. */
 extern SQLiteTbl tagTbl; /*!< Table 'tag'. */
 extern SQLiteTbl msgtagsTbl; /*!< Table 'message_tags'. */
 
+/*
+ * Records management database.
+ */
+extern SQLiteTbl srvcInfTbl; /*!< Table 'service_info'. */
+extern SQLiteTbl strdFlsMsgsTbl; /*!< Table 'stored_files_messages'. */
+
 #endif /* _DB_TABLES_H_ */
