@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #ifndef _MESSAGE_DB_SET_H_
 #define _MESSAGE_DB_SET_H_
 
-#include <QAbstractTableModel>
 #include <QDateTime>
 #include <QMap>
 #include <QString>
@@ -358,37 +357,27 @@ public: /* Database function that have been delegate to the container. */
 	bool vacuum(void);
 
 	/*!
-	 * @brief Return all received messages model.
+	 * @brief Return entries for all received messages.
 	 *
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsRcvdModel(const QStringList &appendedCols);
+	QList<MessageDb::RcvdEntry> msgsRcvdEntries(void) const;
 
 	/*!
-	 * @brief Return received messages within past 90 days.
+	 * @brief Return entries for received messages within past 90 days.
 	 *
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsRcvdWithin90DaysModel(
-	    const QStringList &appendedCols);
+	QList<MessageDb::RcvdEntry> msgsRcvdEntriesWithin90Days(void) const;
 
 	/*!
-	 * @brief Return received messages within given year.
+	 * @brief Return entries for received messages within given year.
 	 *
 	 * @param[in] year         Year number.
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsRcvdInYearModel(const QString &year,
-	    const QStringList &appendedCols);
+	QList<MessageDb::RcvdEntry> msgsRcvdEntriesInYear(
+	    const QString &year) const;
 
 	/*!
 	 * @brief Return list of years (strings) in database.
@@ -430,37 +419,27 @@ public: /* Database function that have been delegate to the container. */
 	    const QString &year) const;
 
 	/*!
-	 * @brief Return all sent messages model.
+	 * @brief Return entries for all sent messages.
 	 *
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsSntModel(const QStringList &appendedCols);
+	QList<MessageDb::SntEntry> msgsSntEntries(void) const;
 
 	/*!
-	 * @brief Return sent messages within past 90 days.
+	 * @brief Return entries for all sent messages within past 90 days.
 	 *
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsSntWithin90DaysModel(
-	    const QStringList &appendedCols);
+	QList<MessageDb::SntEntry> msgsSntEntriesWithin90Days(void) const;
 
 	/*!
-	 * @brief Return sent messages within given year.
+	 * @brief Return entries for sent messages within given year.
 	 *
 	 * @param[in] year         Year number.
-	 * @param[in] appendedCols List of names for added empty columns.
-	 * @return Pointer to model, 0 on failure.
-	 *
-	 * @note The model must not be freed.
+	 * @return List of entries, empty list on failure.
 	 */
-	QAbstractTableModel *msgsSntInYearModel(const QString &year,
-	    const QStringList &appendedCols);
+	QList<MessageDb::SntEntry> msgsSntEntriesInYear(
+	    const QString &year) const;
 
 	/*!
 	 * @brief Set message read locally for all received messages.
@@ -544,11 +523,19 @@ public: /* Database function that have been delegate to the container. */
 	QList<MessageDb::MsgId> getAllMessageIDsFromDB(void) const;
 
 	/*!
-	 * @brief Return all message ID from database without attachment.
+	 * @brief Return all IDs of messages without attachment.
 	 *
-	 * @return message id list.
+	 * @return Message identifier list.
 	 */
-	QStringList getAllMessageIDsWithoutAttach(void) const;
+	QList<qint64> getAllMessageIDsWithoutAttach(void) const;
+
+	/*!
+	 * @brief Return all message IDs from database.
+	 *
+	 * @param[in] messageType Specifies sent or received messages.
+	 * @return Message identifier list.
+	 */
+	QList<qint64> getAllMessageIDs(enum MessageDb::MessageType messageType) const;
 
 	/*!
 	 * @brief Return list of message ids corresponding to given date
@@ -594,18 +581,18 @@ private:
 	 */
 	QStringList _yrly_secKeysIn90Days(void) const;
 
-	inline QAbstractTableModel *_sf_msgsRcvdModel(const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsRcvdModel(const QStringList &appendedCols);
+	inline QList<MessageDb::RcvdEntry> _sf_msgsRcvdEntries(void) const;
+	inline QList<MessageDb::RcvdEntry> _yrly_msgsRcvdEntries(void) const;
 
-	inline QAbstractTableModel *_sf_msgsRcvdWithin90DaysModel(const QStringList &appendedCols);
+	inline QList<MessageDb::RcvdEntry> _sf_msgsRcvdEntriesWithin90Days(void) const;
 	static
-	inline QAbstractTableModel *_yrly_2dbs_attach_msgsRcvdWithin90DaysModel(MessageDb &db, const QString &attachFileName, const QStringList &appendedCols);
+	inline QList<MessageDb::RcvdEntry> _yrly_2dbs_attach_msgsRcvdEntriesWithin90Days(MessageDb &db, const QString &attachFileName);
 	static
-	inline QAbstractTableModel *_yrly_2dbs_msgsRcvdWithin90DaysModel(MessageDb &db0, MessageDb &db1, const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsRcvdWithin90DaysModel(const QStringList &appendedCols);
+	inline QList<MessageDb::RcvdEntry> _yrly_2dbs_msgsRcvdEntriesWithin90Days(MessageDb &db0, MessageDb &db1);
+	inline QList<MessageDb::RcvdEntry> _yrly_msgsRcvdEntriesWithin90Days(void) const;
 
-	inline QAbstractTableModel *_sf_msgsRcvdInYearModel(const QString &year, const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsRcvdInYearModel(const QString &year, const QStringList &appendedCols);
+	inline QList<MessageDb::RcvdEntry> _sf_msgsRcvdEntriesInYear(const QString &year) const;
+	inline QList<MessageDb::RcvdEntry> _yrly_msgsRcvdEntriesInYear(const QString &year) const;
 
 	inline QStringList _sf_msgsYears(enum MessageDb::MessageType type, enum Sorting sorting) const;
 	inline QStringList _yrly_msgsYears(enum MessageDb::MessageType type, enum Sorting sorting) const;
@@ -619,18 +606,18 @@ private:
 	inline int _sf_msgsUnreadInYear(enum MessageDb::MessageType type, const QString &year) const;
 	inline int _yrly_msgsUnreadInYear(enum MessageDb::MessageType type, const QString &year) const;
 
-	inline QAbstractTableModel *_sf_msgsSntModel(const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsSntModel(const QStringList &appendedCols);
+	inline QList<MessageDb::SntEntry> _sf_msgsSntEntries(void) const;
+	inline QList<MessageDb::SntEntry> _yrly_msgsSntEntries(void) const;
 
-	inline QAbstractTableModel *_sf_msgsSntWithin90DaysModel(const QStringList &appendedCols);
+	inline QList<MessageDb::SntEntry> _sf_msgsSntEntriesWithin90Days(void) const;
 	static
-	inline QAbstractTableModel *_yrly_2dbs_attach_msgsSntWithin90DaysModel(MessageDb &db, const QString &attachFileName, const QStringList &appendedCols);
+	inline QList<MessageDb::SntEntry> _yrly_2dbs_attach_msgsSntEntriesWithin90Days(MessageDb &db, const QString &attachFileName);
 	static
-	inline QAbstractTableModel *_yrly_2dbs_msgsSntWithin90DaysModel(MessageDb &db0, MessageDb &db1, const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsSntWithin90DaysModel(const QStringList &appendedCols);
+	inline QList<MessageDb::SntEntry> _yrly_2dbs_msgsSntEntriesWithin90Days(MessageDb &db0, MessageDb &db1);
+	inline QList<MessageDb::SntEntry> _yrly_msgsSntEntriesWithin90Days(void) const;
 
-	inline QAbstractTableModel *_sf_msgsSntInYearModel(const QString &year, const QStringList &appendedCols);
-	inline QAbstractTableModel *_yrly_msgsSntInYearModel(const QString &year, const QStringList &appendedCols);
+	inline QList<MessageDb::SntEntry> _sf_msgsSntEntriesInYear(const QString &year) const;
+	inline QList<MessageDb::SntEntry> _yrly_msgsSntEntriesInYear(const QString &year) const;
 
 	inline bool _sf_smsgdtSetAllReceivedLocallyRead(bool read);
 	inline bool _yrly_smsgdtSetAllReceivedLocallyRead(bool read);
@@ -659,8 +646,11 @@ private:
 	inline QList<MessageDb::MsgId> _sf_getAllMessageIDsFromDB(void) const;
 	inline QList<MessageDb::MsgId> _yrly_getAllMessageIDsFromDB(void) const;
 
-	inline QStringList _sf_getAllMessageIDsWithoutAttach(void) const;
-	inline QStringList _yrly_getAllMessageIDsWithoutAttach(void) const;
+	inline QList<qint64> _sf_getAllMessageIDsWithoutAttach(void) const;
+	inline QList<qint64> _yrly_getAllMessageIDsWithoutAttach(void) const;
+
+	inline QList<qint64> _sf_getAllMessageIDs(enum MessageDb::MessageType messageType) const;
+	inline QList<qint64> _yrly_getAllMessageIDs(enum MessageDb::MessageType messageType) const;
 
 	inline QList<MessageDb::MsgId> _sf_msgsDateInterval(const QDate &fromDate, const QDate &toDate, enum MessageDirection msgDirect) const;
 	inline QList<MessageDb::MsgId> _yrly_msgsDateInterval(const QDate &fromDate, const QDate &toDate, enum MessageDirection msgDirect) const;
