@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
  * the two.
  */
 
+#include <QRegExp>
 #include <QSqlDatabase>
 #include <QSqlError>
 #include <QSqlQuery>
@@ -31,6 +32,40 @@
 #include "src/io/tag_db.h"
 #include "src/log/log.h"
 
+#define DFLT_COLOUR "ffffff"
+
+TagDb::TagEntry::TagEntry(void)
+    : id(-1),
+    name(),
+    colour(DFLT_COLOUR)
+{
+}
+
+TagDb::TagEntry::TagEntry(int i, const QString &n, const QString &c)
+    : id(i),
+    name(n),
+    colour(isValidColourStr(c) ? c : DFLT_COLOUR)
+{
+}
+
+bool TagDb::TagEntry::isValid(void) const
+{
+	return (id >= 0) && !name.isEmpty() && (6 == colour.size());
+}
+
+bool TagDb::TagEntry::isValidColourStr(const QString &colourStr)
+{
+	QRegExp re("^[a-f0-9]{6,6}$");
+
+	return re.exactMatch(colourStr);
+}
+
+bool TagDb::TagEntry::operator==(const TagEntry &other) const
+{
+	return (id == other.id) && (name == other.name) &&
+	    (colour == other.colour);
+}
+
 TagDb::TagDb(const QString &connectionName)
     : SQLiteDb(connectionName)
 {
@@ -83,34 +118,6 @@ bool TagDb::insertTag(const QString &tagName, const QString &tagColor)
 	return true;
 }
 
-bool TagDb::insertUpdateWebDatovkaTag(int id,
-    const QString &tagName, const QString &tagColor)
-{
-	QSqlQuery query(m_db);
-
-	QString queryStr = "INSERT OR REPLACE INTO tag (id, tag_name, tag_color) "
-	    "VALUES (:tag_id, :tag_name, :tag_color)";
-
-	if (!query.prepare(queryStr)) {
-		logErrorNL("Cannot prepare SQL query: %s.",
-		    query.lastError().text().toUtf8().constData());
-		return false;
-	}
-
-	query.bindValue(":tag_id", id);
-	query.bindValue(":tag_name", tagName);
-	query.bindValue(":tag_color", tagColor);
-
-	if (!query.exec()) {
-		logErrorNL("Cannot execute SQL query: %s.",
-		    query.lastError().text().toUtf8().constData());
-		return false;
-	}
-
-	return true;
-}
-
-
 bool TagDb::updateTag(int id, const QString &tagName, const QString &tagColor)
 {
 	QSqlQuery query(m_db);
@@ -191,7 +198,7 @@ bool TagDb::deleteAllTags(void)
 }
 
 
-TagItem TagDb::getTagData(int id)
+TagDb::TagEntry TagDb::getTagData(int id) const
 {
 	QSqlQuery query(m_db);
 
@@ -204,7 +211,7 @@ TagItem TagDb::getTagData(int id)
 	query.bindValue(":id", id);
 	if (query.exec() && query.isActive() &&
 	    query.first() && query.isValid()) {
-		return TagItem(id, query.value(0).toString(),
+		return TagEntry(id, query.value(0).toString(),
 		    query.value(1).toString());
 	} else {
 		logErrorNL(
@@ -214,13 +221,13 @@ TagItem TagDb::getTagData(int id)
 	}
 
 fail:
-	return TagItem();
+	return TagEntry();
 }
 
-QList<TagItem> TagDb::getAllTags(void)
+QList<TagDb::TagEntry> TagDb::getAllTags(void) const
 {
 	QSqlQuery query(m_db);
-	QList<TagItem> tagList;
+	QList<TagEntry> tagList;
 
 	QString queryStr = "SELECT * FROM tag ORDER BY tag_name ASC";
 	if (!query.prepare(queryStr)) {
@@ -232,7 +239,7 @@ QList<TagItem> TagDb::getAllTags(void)
 	if (query.exec() && query.isActive()) {
 		query.first();
 		while (query.isValid()) {
-			tagList.append(TagItem(query.value(0).toInt(),
+			tagList.append(TagEntry(query.value(0).toInt(),
 			    query.value(1).toString(),
 			    query.value(2).toString()));
 			query.next();
@@ -245,13 +252,14 @@ QList<TagItem> TagDb::getAllTags(void)
 
 	return tagList;
 fail:
-	return QList<TagItem>();
+	return QList<TagEntry>();
 }
 
-TagItemList TagDb::getMessageTags(const QString &userName, quint64 msgId)
+QList<TagDb::TagEntry> TagDb::getMessageTags(const QString &userName,
+    quint64 msgId) const
 {
 	QSqlQuery query(m_db);
-	TagItemList tagList;
+	QList<TagEntry> tagList;
 
 	QString queryStr = "SELECT t.id, t.tag_name, t.tag_color "
 	    "FROM tag AS t "
@@ -270,7 +278,7 @@ TagItemList TagDb::getMessageTags(const QString &userName, quint64 msgId)
 	if (query.exec() && query.isActive()) {
 		query.first();
 		while (query.isValid()) {
-			tagList.append(TagItem(query.value(0).toInt(),
+			tagList.append(TagEntry(query.value(0).toInt(),
 			    query.value(1).toString(),
 			    query.value(2).toString()));
 			query.next();
@@ -283,7 +291,7 @@ TagItemList TagDb::getMessageTags(const QString &userName, quint64 msgId)
 	}
 
 fail:
-	return TagItemList();
+	return QList<TagEntry>();
 }
 
 bool TagDb::removeAllTagsFromMsg(const QString &userName, qint64 msgId)
@@ -401,7 +409,7 @@ bool TagDb::removeAllMsgTagsFromAccount(const QString &userName)
 	return true;
 }
 
-QList<qint64> TagDb::getMsgIdsContainSearchTagText(const QString &text)
+QList<qint64> TagDb::getMsgIdsContainSearchTagText(const QString &text) const
 {
 	QSqlQuery query(m_db);
 	QList<qint64> msgIdList;
@@ -447,3 +455,8 @@ QList<class SQLiteTbl *> TagDb::listOfTables(void)
 }
 
 TagDb *globTagDbPtr = 0;
+
+uint qHash(const TagDb::TagEntry &entry, uint seed)
+{
+	return ::qHash(entry.id, seed);
+}
