@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 #include <QList>
 #include <QString>
 
-#include "src/delegates/tag_item.h"
 #include "src/io/sqlite/db.h"
 
 /*!
@@ -36,6 +35,61 @@
 class TagDb : public SQLiteDb {
 
 public:
+	/*!
+	 * @brief Encapsulates database tag entry.
+	 */
+	class TagEntry {
+	public:
+		/*!
+		 * @brief Constructor of invalid tag entry.
+		 *
+		 * @note Identifier is -1, has empty name, colour is 'ffffff';
+		 */
+		TagEntry(void);
+
+		/*!
+		 * @brief Constructs a tag entry from supplied parameters.
+		 *
+		 * @param[in] i Tag identifier.
+		 * @param[in] n Tag name.
+		 * @param[in] c Tag colour in hex format without the leading hashtag.
+		 */
+		TagEntry(int i, const QString &n, const QString &c);
+
+		/*!
+		 * @brief Check for validity.
+		 *
+		 * @note Invalid tag has id equal to -1, empty name and bogus colour.
+		 *
+		 * @return True if tag contains valid data.
+		 */
+		bool isValid(void) const;
+
+		/*!
+		 * @brief Returns true if colour string is valid.
+		 *
+		 * @param[in] colourStr Colour string.
+		 * @return True if colour string is valid.
+		 */
+		static
+		bool isValidColourStr(const QString &colourStr);
+
+		/*!
+		 * @brief Comparison operator.
+		 *
+		 * @param[in] other Another object to compare this one with.
+		 * @return True is the other entry is equal to this one.
+		 */
+		bool operator==(const TagEntry &other) const;
+
+		int id; /*!< Tag identifier. */
+		QString name; /*!< Name of the tag. */
+		QString colour; /*!<
+		                 * Colour of the tag in hex format without
+		                 * the leading hashtag.
+		                 */
+	};
+
 	/*!
 	 * @brief Constructor.
 	 *
@@ -60,17 +114,6 @@ public:
 	 */
 	bool insertTag(const QString &tagName, const QString &tagColor);
 
-	/*!
-	 * @brief Insert new or update webdatovka tag into database file.
-	 *
-	 * @param[in] id            id of tag form webdatovka.
-	 * @param[in] tagName       text label of tag.
-	 * @param[in] tagColor      color of tag in HEX format.
-	 * @return True on success, false on any error.
-	 */
-	bool insertUpdateWebDatovkaTag(int id, const QString &tagName,
-	    const QString &tagColor);
-
 	/*!
 	 * @brief Update tag in database file.
 	 *
@@ -102,14 +145,14 @@ public:
 	 * @param[in] id    id of tag.
 	 * @return tag struct with data.
 	 */
-	TagItem getTagData(int id);
+	TagEntry getTagData(int id) const;
 
 	/*!
 	 * @brief Get all tags from database file.
 	 *
-	 * @return Llist of TagItem.
+	 * @return List of tag entries.
 	 */
-	QList<TagItem> getAllTags(void);
+	QList<TagEntry> getAllTags(void) const;
 
 	/*!
 	 * @brief Get all tags related to given message.
@@ -118,8 +161,8 @@ public:
 	 * @param[in] dmgId Message identifier.
 	 * @return List of tags related to message.
 	 */
-	TagItemList getMessageTags(const QString &userName,
-	    const quint64 msgId);
+	QList<TagEntry> getMessageTags(const QString &userName,
+	    const quint64 msgId) const;
 
 	/*!
 	 * @brief Delete all tags for message ID
@@ -165,7 +208,7 @@ public:
 	 * @param[in] text    search text of tag name.
 	 * @return List of message IDs related to tag text.
 	 */
-	QList<qint64> getMsgIdsContainSearchTagText(const QString &text);
+	QList<qint64> getMsgIdsContainSearchTagText(const QString &text) const;
 
 private:
 	/*!
@@ -182,4 +225,13 @@ private:
  */
 extern TagDb *globTagDbPtr;
 
+/*!
+ * @brief Return a hash value for the supplied tag entry.
+ *
+ * @param[in] entry Tag entry to compute hash from.
+ * @param[in] seed Is used to initialise the hash if specified.
+ * @return Hashed tag entry.
+ */
+uint qHash(const TagDb::TagEntry &entry, uint seed = 0);
+
 #endif /* _TAG_DB_H_ */
