@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,8 +76,6 @@
 #define internalIdUserNameIndex(intId) \
 	(((unsigned) (intId)) >> TYPE_BITS)
 
-AccountsMap AccountModel::globAccounts;
-
 AccountModel::AccountModel(QObject *parent)
     : QAbstractItemModel(parent),
     m_userNames(),
@@ -306,12 +304,8 @@ QVariant AccountModel::data(const QModelIndex &index, int role) const
 	case Qt::DecorationRole:
 		switch (type) {
 		case nodeAccountTop:
-			if (isWebDatovkaAccount(uName)) {
-				return QIcon(":/mojeid.png");
-			} else {
-				return QIcon(ICON_3PARTY_PATH +
-				    QStringLiteral("letter_16.png"));
-			}
+			return QIcon(ICON_3PARTY_PATH +
+			    QStringLiteral("letter_16.png"));
 			break;
 		case nodeRecentReceived:
 		case nodeReceived:
