@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,16 +22,16 @@
  */
 
 #include <QFont>
-#include <QIcon>
 
 #include "src/common.h"
 #include "src/delegates/tag_item.h"
-#include "src/io/tag_db.h" /* Direct access to tag database, */
+#include "src/graphics/graphics.h"
 #include "src/io/db_tables.h"
 #include "src/io/dbs.h"
-#include "src/io/tag_db_container.h"
-#include "src/models/messages_model.h"
 #include "src/io/message_db.h"
+#include "src/io/records_management_db.h"
+#include "src/io/tag_db.h" /* Direct access to tag database, */
+#include "src/models/messages_model.h"
 
 const int DbMsgsTblModel::rcvdMsgsColCnt(8);
 const int DbMsgsTblModel::sntMsgsColCnt(7);
@@ -44,7 +44,8 @@ const int DbMsgsTblModel::sntMsgsColCnt(7);
 
 DbMsgsTblModel::DbMsgsTblModel(enum DbMsgsTblModel::Type type, QObject *parent)
     : TblModel(parent),
-    m_type(type)
+    m_type(type),
+    m_dsIco(ICON_3PARTY_PATH "up_16.png")
 {
 }
 
@@ -52,17 +53,60 @@ QVariant DbMsgsTblModel::data(const QModelIndex &index, int role) const
 {
 	int dataType;
 
-	/* Leave additional to delegates. */
+#define TAGS_OFFS 1 /* Tags are located behind upload information. */
+
+	/* Draw upload information. */
+	/* TODO -- This is only a temporal solution. */
 	switch (m_type) {
 	case WORKING_RCVD:
-	case DUMMY_RCVD:
-		if (index.column() > PROCSNG_COL) {
+		if (index.column() == (PROCSNG_COL + TAGS_OFFS)) {
+			QStringList locations(
+			    _data(index, Qt::DisplayRole).toStringList());
+			switch (role) {
+			case Qt::DecorationRole:
+				return locations.isEmpty() ? QVariant() : m_dsIco;
+				break;
+			case Qt::ToolTipRole:
+				return locations.join("\n");
+				break;
+			default:
+				return QVariant();
+				break;
+			}
+		}
+		break;
+	case WORKING_SNT:
+		if (index.column() == (ATTDOWN_COL + TAGS_OFFS)) {
+			QStringList locations(
+			    _data(index, Qt::DisplayRole).toStringList());
+			switch (role) {
+			case Qt::DecorationRole:
+				return locations.isEmpty() ? QVariant() : m_dsIco;
+				break;
+			case Qt::ToolTipRole:
+				return locations.join("\n");
+				break;
+			default:
+				return QVariant();
+				break;
+			}
+		}
+		break;
+	default:
+		Q_ASSERT(0);
+		return QVariant();
+		break;
+	}
+
+	/* Leave additional tags to delegates. */
+	switch (m_type) {
+	case WORKING_RCVD:
+		if (index.column() > (PROCSNG_COL + TAGS_OFFS)) {
 			return _data(index, role);
 		}
 		break;
 	case WORKING_SNT:
-	case DUMMY_SNT:
-		if (index.column() > ATTDOWN_COL) {
+		if (index.column() > (ATTDOWN_COL + TAGS_OFFS)) {
 			return _data(index, role);
 		}
 		break;
@@ -72,6 +116,8 @@ QVariant DbMsgsTblModel::data(const QModelIndex &index, int role) const
 		break;
 	}
 
+#undef TAGS_OFFS
+
 	switch (role) {
 	case Qt::DisplayRole:
 		dataType = _headerData(index.column(), Qt::Horizontal,
@@ -211,13 +257,11 @@ QVariant DbMsgsTblModel::headerData(int section, Qt::Orientation orientation,
 	/* Draw additional. */
 	switch (m_type) {
 	case WORKING_RCVD:
-	case DUMMY_RCVD:
 		if (section > PROCSNG_COL) {
 			return _headerData(section, orientation, role);
 		}
 		break;
 	case WORKING_SNT:
-	case DUMMY_SNT:
 		if (section > ATTDOWN_COL) {
 			return _headerData(section, orientation, role);
 		}
@@ -300,95 +344,170 @@ QVariant DbMsgsTblModel::headerData(int section, Qt::Orientation orientation,
 	}
 }
 
-void DbMsgsTblModel::setQuery(QSqlQuery &query, enum DbMsgsTblModel::Type type)
+void DbMsgsTblModel::appendData(const QList<MessageDb::RcvdEntry> &entryList,
+    int appendedColsNum)
 {
-	setType(type);
-	TblModel::setQuery(query);
-	/* TODO -- Check whether type matches query. */
+	if (Q_UNLIKELY(appendedColsNum < 0)) {
+		Q_ASSERT(0);
+		return;
+	}
+
+	/* Set column count if the model is empty. */
+	if (rowCount() == 0) {
+		beginResetModel();
+		m_type = WORKING_RCVD;
+		m_columnCount = MessageDb::rcvdItemIds.size() + appendedColsNum;
+		endResetModel();
+	} else {
+		if (Q_UNLIKELY(m_type != WORKING_RCVD)) {
+			Q_ASSERT(0);
+			return;
+		}
+		if (Q_UNLIKELY(m_columnCount !=
+		        (MessageDb::rcvdItemIds.size() + appendedColsNum))) {
+			Q_ASSERT(0);
+			return;
+		}
+	}
+
+	if (entryList.isEmpty()) {
+		/* Don't do anything. */
+		return;
+	}
+
+	beginInsertRows(QModelIndex(), rowCount(),
+	    rowCount() + entryList.size() - 1);
+
+	foreach (const MessageDb::RcvdEntry &entry, entryList) {
+
+		reserveSpace();
+
+		QVector<QVariant> row(m_columnCount);
+
+		row[DMID_COL] = entry.dmId;
+		row[ANNOT_COL] = entry.dmAnnotation;
+		row[2] = entry.dmSender;
+		row[DELIVERY_COL] = entry.dmDeliveryTime;
+		row[ACCEPT_COL] = entry.dmAcceptanceTime;
+		row[READLOC_COL] = entry.readLocally;
+		row[ATTDOWN_COL] = entry.isDownloaded;
+		row[PROCSNG_COL] = entry.processStatus;
+
+		m_data[m_rowCount++] = row;
+	}
+
+	endInsertRows();
 }
 
-bool DbMsgsTblModel::appendQueryData(QSqlQuery &query,
-    enum DbMsgsTblModel::Type type)
+void DbMsgsTblModel::appendData(const QList<MessageDb::SntEntry> &entryList,
+    int appendedColsNum)
 {
-	if (type != m_type) {
-		return false;
+	if (Q_UNLIKELY(appendedColsNum < 0)) {
+		Q_ASSERT(0);
+		return;
 	}
-	return TblModel::appendQueryData(query);
+
+	/* Set column count if the model is empty. */
+	if (rowCount() == 0) {
+		beginResetModel();
+		m_type = WORKING_SNT;
+		m_columnCount = MessageDb::sntItemIds.size() + appendedColsNum;
+		endResetModel();
+	} else {
+		if (Q_UNLIKELY(m_type != WORKING_SNT)) {
+			Q_ASSERT(0);
+			return;
+		}
+		if (Q_UNLIKELY(m_columnCount !=
+		        (MessageDb::sntItemIds.size() + appendedColsNum))) {
+			Q_ASSERT(0);
+			return;
+		}
+	}
+
+	if (entryList.isEmpty()) {
+		/* Don't do anything. */
+		return;
+	}
+
+	beginInsertRows(QModelIndex(), rowCount(),
+	    rowCount() + entryList.size() - 1);
+
+	foreach (const MessageDb::SntEntry &entry, entryList) {
+
+		reserveSpace();
+
+		QVector<QVariant> row(m_columnCount);
+
+		row[DMID_COL] = entry.dmId;
+		row[ANNOT_COL] = entry.dmAnnotation;
+		row[2] = entry.dmRecipient;
+		row[DELIVERY_COL] = entry.dmDeliveryTime;
+		row[ACCEPT_COL] = entry.dmAcceptanceTime;
+		row[5] = entry.dmMessageStatus;
+		row[ATTDOWN_COL] = entry.isDownloaded;
+
+		m_data[m_rowCount++] = row;
+	}
+
+	endInsertRows();
 }
 
 bool DbMsgsTblModel::setType(enum DbMsgsTblModel::Type type)
 {
 	m_type = type;
 
-	switch (m_type) {
-	case DUMMY_RCVD:
-		return setRcvdHeader(QStringList()); /* FIXME */
-		break;
-	case DUMMY_SNT:
-		return setSntHeader(QStringList()); /* FIXME */
-		break;
-	default:
-		return true;
-		break;
+	return true;
+}
+
+static
+void appendHeaderColumns(DbMsgsTblModel *model, int dfltHdrSize,
+    const QList<DbMsgsTblModel::AppendedCol> &appendedCols)
+{
+	if ((model == Q_NULLPTR) || (dfltHdrSize < 0)) {
+		Q_ASSERT(0);
+		return;
+	}
+
+	for (int i = 0; i < appendedCols.size(); ++i) {
+		/* Description. */
+		model->setHeaderData(dfltHdrSize + i, Qt::Horizontal,
+		    appendedCols.at(i).display, Qt::DisplayRole);
+		model->setHeaderData(dfltHdrSize + i, Qt::Horizontal,
+		    appendedCols.at(i).decoration, Qt::DecorationRole);
+		model->setHeaderData(dfltHdrSize + i, Qt::Horizontal,
+		    appendedCols.at(i).toolTip, Qt::ToolTipRole);
+		/* Data type. */
+		model->setHeaderData(dfltHdrSize + i, Qt::Horizontal,
+		    DB_APPENDED_VARIANT, ROLE_MSGS_DB_ENTRY_TYPE);
 	}
 }
 
-const QVector<QString> &DbMsgsTblModel::rcvdItemIds(void)
+bool DbMsgsTblModel::setRcvdHeader(const QList<AppendedCol> &appendedCols)
 {
-	static QVector<QString> ids;
-	if (ids.size() == 0) {
-		ids.append("dmID");
-		ids.append("dmAnnotation");
-		ids.append("dmSender");
-		ids.append("dmDeliveryTime");
-		ids.append("dmAcceptanceTime");
-		ids.append("read_locally");
-		ids.append("is_downloaded");
-		ids.append("process_status");
-	}
-	return ids;
-}
-
-const QVector<QString> &DbMsgsTblModel::sntItemIds(void)
-{
-	static QVector<QString> ids;
-	if (ids.size() == 0) {
-	    ids.append("dmID");
-	    ids.append("dmAnnotation");
-	    ids.append("dmRecipient");
-	    ids.append("dmDeliveryTime");
-	    ids.append("dmAcceptanceTime");
-	    ids.append("dmMessageStatus");
-	    ids.append("is_downloaded");
-	}
-	return ids;
-}
-
-bool DbMsgsTblModel::setRcvdHeader(const QStringList &appendedCols)
-{
-	for (int i = 0; i < rcvdItemIds().size(); ++i) {
+	for (int i = 0; i < MessageDb::rcvdItemIds.size(); ++i) {
 		/* TODO -- Handle the joined tables in a better way. */
-		if (msgsTbl.attrProps.find(rcvdItemIds()[i]) !=
+		if (msgsTbl.attrProps.find(MessageDb::rcvdItemIds[i]) !=
 		    msgsTbl.attrProps.end()) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
-			    msgsTbl.attrProps.value(rcvdItemIds()[i]).desc,
+			    msgsTbl.attrProps.value(MessageDb::rcvdItemIds[i]).desc,
 			    Qt::DisplayRole);
 			/* Data type. */
 			setHeaderData(i, Qt::Horizontal,
-			    msgsTbl.attrProps.value(rcvdItemIds()[i]).type,
+			    msgsTbl.attrProps.value(MessageDb::rcvdItemIds[i]).type,
 			    ROLE_MSGS_DB_ENTRY_TYPE);
-		} else if (smsgdtTbl.attrProps.find(rcvdItemIds()[i]) !=
+		} else if (smsgdtTbl.attrProps.find(MessageDb::rcvdItemIds[i]) !=
 		    smsgdtTbl.attrProps.end()) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
-			    smsgdtTbl.attrProps.value(rcvdItemIds()[i]).desc,
+			    smsgdtTbl.attrProps.value(MessageDb::rcvdItemIds[i]).desc,
 			    Qt::DisplayRole);
 			/* Data type. */
 			setHeaderData(i, Qt::Horizontal,
-			    smsgdtTbl.attrProps.value(rcvdItemIds()[i]).type,
+			    smsgdtTbl.attrProps.value(MessageDb::rcvdItemIds[i]).type,
 			    ROLE_MSGS_DB_ENTRY_TYPE);
-		} else if ("is_downloaded" == rcvdItemIds()[i]) {
+		} else if ("is_downloaded" == MessageDb::rcvdItemIds[i]) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
 			    tr("Attachments downloaded"), Qt::DisplayRole);
@@ -396,7 +515,7 @@ bool DbMsgsTblModel::setRcvdHeader(const QStringList &appendedCols)
 			setHeaderData(i, Qt::Horizontal,
 			    DB_BOOL_ATTACHMENT_DOWNLOADED,
 			    ROLE_MSGS_DB_ENTRY_TYPE);
-		} else if ("process_status" == rcvdItemIds()[i]) {
+		} else if ("process_status" == MessageDb::rcvdItemIds[i]) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
 			    tr("Processing state"), Qt::DisplayRole);
@@ -408,33 +527,26 @@ bool DbMsgsTblModel::setRcvdHeader(const QStringList &appendedCols)
 		}
 	}
 
-	for (int i = 0; i < appendedCols.size(); ++i) {
-		/* Description. */
-		setHeaderData(rcvdItemIds().size() + i, Qt::Horizontal,
-		    appendedCols.at(i), Qt::DisplayRole);
-		/* Data type. */
-		setHeaderData(rcvdItemIds().size() + i, Qt::Horizontal,
-		    DB_APPENDED_VARIANT, ROLE_MSGS_DB_ENTRY_TYPE);
-	}
+	appendHeaderColumns(this, MessageDb::rcvdItemIds.size(), appendedCols);
 
 	return true;
 }
 
-bool DbMsgsTblModel::setSntHeader(const QStringList &appendedCols)
+bool DbMsgsTblModel::setSntHeader(const QList<AppendedCol> &appendedCols)
 {
-	for (int i = 0; i < sntItemIds().size(); ++i) {
+	for (int i = 0; i < MessageDb::sntItemIds.size(); ++i) {
 		/* TODO -- Handle the joined tables in a better way. */
-		if (msgsTbl.attrProps.find(sntItemIds()[i]) !=
+		if (msgsTbl.attrProps.find(MessageDb::sntItemIds[i]) !=
 		    msgsTbl.attrProps.end()) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
-			    msgsTbl.attrProps.value(sntItemIds()[i]).desc,
+			    msgsTbl.attrProps.value(MessageDb::sntItemIds[i]).desc,
 			    Qt::DisplayRole);
 			/* Data type. */
 			setHeaderData(i, Qt::Horizontal,
-			    msgsTbl.attrProps.value(sntItemIds()[i]).type,
+			    msgsTbl.attrProps.value(MessageDb::sntItemIds[i]).type,
 			    ROLE_MSGS_DB_ENTRY_TYPE);
-		} else if ("is_downloaded" == sntItemIds()[i]) {
+		} else if ("is_downloaded" == MessageDb::sntItemIds[i]) {
 			/* Description. */
 			setHeaderData(i, Qt::Horizontal,
 			    tr("Attachments downloaded"), Qt::DisplayRole);
@@ -447,14 +559,7 @@ bool DbMsgsTblModel::setSntHeader(const QStringList &appendedCols)
 		}
 	}
 
-	for (int i = 0; i < appendedCols.size(); ++i) {
-		/* Description. */
-		setHeaderData(sntItemIds().size() + i, Qt::Horizontal,
-		    appendedCols.at(i), Qt::DisplayRole);
-		/* Data type. */
-		setHeaderData(sntItemIds().size() + i, Qt::Horizontal,
-		    DB_APPENDED_VARIANT, ROLE_MSGS_DB_ENTRY_TYPE);
-	}
+	appendHeaderColumns(this, MessageDb::sntItemIds.size(), appendedCols);
 
 	return true;
 }
@@ -523,25 +628,9 @@ bool DbMsgsTblModel::overrideProcessing(qint64 dmId,
 	return false;
 }
 
-DbMsgsTblModel &DbMsgsTblModel::dummyModel(enum DbMsgsTblModel::Type type)
-{
-	static DbMsgsTblModel dummy(DUMMY_RCVD);
-	dummy.setType(type);
-	return dummy;
-}
-
 bool DbMsgsTblModel::fillTagsColumn(const QString &userName, int col)
 {
-	TagDb *tagDb = 0;
-
-	if (isWebDatovkaAccount(userName)) {
-		tagDb = globWebDatovkaTagDbPtr->
-		     accessTagDb(getWebDatovkaTagDbPrefix(userName));
-	} else {
-		tagDb = globTagDbPtr;
-	}
-
-	if (0 == tagDb) {
+	if (Q_NULLPTR == globTagDbPtr) {
 		return false;
 	}
 
@@ -563,7 +652,7 @@ bool DbMsgsTblModel::fillTagsColumn(const QString &userName, int col)
 
 	for (int row = 0; row < rowCount(); ++row) {
 		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
-		TagItemList tagList(tagDb->getMessageTags(userName, dmId));
+		TagItemList tagList(globTagDbPtr->getMessageTags(userName, dmId));
 		tagList.sortNames();
 		m_data[row][col] = QVariant::fromValue(tagList);
 	}
@@ -577,16 +666,7 @@ bool DbMsgsTblModel::fillTagsColumn(const QString &userName, int col)
 bool DbMsgsTblModel::refillTagsColumn(const QString &userName,
     const QList<qint64> &dmIds, int col)
 {
-	TagDb *tagDb = 0;
-
-	if (isWebDatovkaAccount(userName)) {
-		tagDb = globWebDatovkaTagDbPtr->
-		    accessTagDb(getWebDatovkaTagDbPrefix(userName));
-	} else {
-		tagDb = globTagDbPtr;
-	}
-
-	if (0 == tagDb) {
+	if (Q_NULLPTR == globTagDbPtr) {
 		return false;
 	}
 
@@ -610,7 +690,7 @@ bool DbMsgsTblModel::refillTagsColumn(const QString &userName,
 		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
 		if (dmIds.contains(dmId)) {
 			TagItemList tagList(
-			    tagDb->getMessageTags(userName, dmId));
+			    globTagDbPtr->getMessageTags(userName, dmId));
 			tagList.sortNames();
 			m_data[row][col] = QVariant::fromValue(tagList);
 			emit dataChanged(TblModel::index(row, col),
@@ -621,12 +701,87 @@ bool DbMsgsTblModel::refillTagsColumn(const QString &userName,
 	return true;
 }
 
-void DbMsgsTblModel::setQuery(QSqlQuery &query)
+bool DbMsgsTblModel::setRecordsManagementIcon(void)
 {
-	TblModel::setQuery(query);
+	if (Q_NULLPTR == globRecordsManagementDbPtr) {
+		m_dsIco = QIcon(ICON_3PARTY_PATH "up_16.png");
+		return false;
+	}
+
+	RecordsManagementDb::ServiceInfoEntry entry(
+	    globRecordsManagementDbPtr->serviceInfo());
+	if (!entry.isValid() || entry.logoSvg.isEmpty()) {
+		m_dsIco = QIcon(ICON_3PARTY_PATH "up_16.png");
+		return false;
+	}
+	QPixmap pixmap(Graphics::pixmapFromSvg(entry.logoSvg, 16));
+	if (pixmap.isNull()) {
+		m_dsIco = QIcon(ICON_3PARTY_PATH "up_16.png");
+		return false;
+	}
+
+	m_dsIco = QIcon(pixmap);
+	return true;
 }
 
-bool DbMsgsTblModel::appendQueryData(QSqlQuery &query)
+bool DbMsgsTblModel::fillRecordsManagementColumn(int col)
 {
-	return TblModel::appendQueryData(query);
+	if (Q_NULLPTR == globRecordsManagementDbPtr) {
+		return false;
+	}
+
+	/* Check indexes into column. */
+	if (col >= 0) {
+		if (col > columnCount()) {
+			return false;
+		}
+	} else {
+		col += columnCount();
+		if (col < 0) {
+			return false;
+		}
+	}
+
+	for (int row = 0; row < rowCount(); ++row) {
+		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
+		m_data[row][col] =
+		    globRecordsManagementDbPtr->storedMsgLocations(dmId);
+	}
+
+	emit dataChanged(TblModel::index(0, col),
+	    TblModel::index(rowCount() - 1, col));
+
+	return true;
+}
+
+bool DbMsgsTblModel::refillRecordsManagementColumn(const QList<qint64> &dmIds,
+    int col)
+{
+	if (Q_NULLPTR == globRecordsManagementDbPtr) {
+		return false;
+	}
+
+	/* Check indexes into column. */
+	if (col >= 0) {
+		if (col > columnCount()) {
+			return false;
+		}
+	} else {
+		col += columnCount();
+		if (col < 0) {
+			return false;
+		}
+	}
+
+	for (int row = 0; row < rowCount(); ++row) {
+		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
+		if (dmIds.contains(dmId)) {
+			m_data[row][col] =
+			    globRecordsManagementDbPtr->storedMsgLocations(dmId);
+			emit dataChanged(TblModel::index(row, col),
+			    TblModel::index(row, col));
+		}
+	}
+
+	return true;
 }
