@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,16 @@
 #include <QString>
 
 #include "src/delegates/tag_item.h"
+#include "src/localisation/localisation.h"
 #include "src/models/sort_filter_proxy_model.h"
 
+const QString SortFilterProxyModel::blankFilterEditStyle(
+    "QLineEdit{background: white;}");
+const QString SortFilterProxyModel::foundFilterEditStyle(
+    "QLineEdit{background: #afffaf;}");
+const QString SortFilterProxyModel::notFoundFilterEditStyle(
+    "QLineEdit{background: #ffafaf;}");
+
 SortFilterProxyModel::SortFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
 {
@@ -92,7 +100,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex &sourceLeft,
 		Q_ASSERT(rightData.canConvert<TagItem>());
 		TagItem leftTagItem(qvariant_cast<TagItem>(leftData));
 		TagItem rightTagItem(qvariant_cast<TagItem>(rightData));
-		return QString::localeAwareCompare(leftTagItem.name,
+		return Localisation::stringCollator.compare(leftTagItem.name,
 		    rightTagItem.name) < 0;
 	} else if (leftData.canConvert<TagItemList>()) {
 		Q_ASSERT(rightData.canConvert<TagItemList>());
@@ -112,7 +120,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex &sourceLeft,
 			}
 
 			/* None of the lists are empty. */
-			int ret = QString::localeAwareCompare(
+			int ret = Localisation::stringCollator.compare(
 			    leftTagList.first().name,
 			    rightTagList.first().name);
 			if (ret < 0) {
