@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,7 +65,7 @@ void TaskDownloadCreditInfo::run(void)
 	    (void *) QThread::currentThreadId());
 }
 
-long TaskDownloadCreditInfo::downloadCreditFromISDS(const QString &userName,
+qint64 TaskDownloadCreditInfo::downloadCreditFromISDS(const QString &userName,
     const QString &dbId)
 {
 	long credit = 0;
