@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,9 @@
 
 #include "src/io/dbs.h"
 #include "src/io/isds_sessions.h"
+#include "src/isds/isds_conversion.h"
 #include "src/log/log.h"
-#include "src/models/accounts_model.h"
+#include "src/settings/accounts.h"
 #include "src/worker/message_emitter.h"
 #include "src/worker/task_download_message.h"
 
@@ -77,7 +78,7 @@ void TaskDownloadMessage::run(void)
 	logDebugLv1NL("%s", "-----------------------------------------------");
 	logDebugLv1NL("Downloading %s message '%" PRId64 "' for account '%s'.",
 	    (MSG_RECEIVED == m_msgDirect) ? "received" : "sent", m_mId.dmId,
-	    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+	    globAccounts[m_userName].accountName().toUtf8().constData());
 	logDebugLv1NL("%s", "-----------------------------------------------");
 
 	m_result = downloadMessage(m_userName, m_mId, true, m_msgDirect,
@@ -87,11 +88,11 @@ void TaskDownloadMessage::run(void)
 		logDebugLv1NL(
 		    "Done downloading message '%" PRId64 "' for account '%s'.",
 		    m_mId.dmId,
-		    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+		    globAccounts[m_userName].accountName().toUtf8().constData());
 	} else {
 		logErrorNL("Downloading message '%" PRId64 "' for account '%s' failed.",
 		    m_mId.dmId,
-		    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+		    globAccounts[m_userName].accountName().toUtf8().constData());
 	}
 
 	emit globMsgProcEmitter.downloadMessageFinished(m_userName, m_mId.dmId,
@@ -253,7 +254,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 
 			/* Store envelope in new location. */
 			Task::storeEnvelope(msgDirect, dbSet,
-			    message->envelope, NULL);
+			    message->envelope);
 		}
 		/* Update message delivery time. */
 		mId.deliveryTime = newDeliveryTime;
@@ -261,7 +262,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 
 	/* Store the message. */
 	Task::storeMessage(signedMsg, msgDirect, dbSet, message,
-	    progressLabel, NULL);
+	    progressLabel);
 
 	emit globMsgProcEmitter.progressChange(progressLabel, 90);
 
@@ -339,7 +340,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessageAuthor(
 	}
 
 	if (messageDb.updateMessageAuthorInfo(dmId,
-	        convertSenderTypeToString((int) *sender_type), sender_name)) {
+	        IsdsConversion::senderTypeToStr((int) *sender_type), sender_name)) {
 		logDebugLv0NL(
 		    "Author information of message '%" PRId64 "' were updated.",
 		    dmId);
