@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,9 @@
 
 #include "src/io/dbs.h"
 #include "src/io/isds_sessions.h"
+#include "src/isds/isds_conversion.h"
 #include "src/log/log.h"
-#include "src/models/accounts_model.h"
+#include "src/settings/accounts.h"
 #include "src/worker/message_emitter.h"
 #include "src/worker/pool.h" /* List with whole messages. */
 #include "src/worker/task_download_message.h" /* List with whole messages. */
@@ -92,7 +93,7 @@ void TaskDownloadMessageList::run(void)
 	logDebugLv1NL("%s", "-----------------------------------------------");
 	logDebugLv1NL("Downloading %s message list for account '%s'.",
 	    (MSG_RECEIVED == m_msgDirect) ? "received" : "sent",
-	    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+	    globAccounts[m_userName].accountName().toUtf8().constData());
 	logDebugLv1NL("%s", "-----------------------------------------------");
 
 	if (MSG_RECEIVED == m_msgDirect) {
@@ -109,10 +110,10 @@ void TaskDownloadMessageList::run(void)
 
 	if (DL_SUCCESS == m_result) {
 		logDebugLv1NL("Done downloading message list for account '%s'.",
-		    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+		    globAccounts[m_userName].accountName().toUtf8().constData());
 	} else {
 		logErrorNL("Downloading message list for account '%s' failed.",
-		    AccountModel::globAccounts[m_userName].accountName().toUtf8().constData());
+		    globAccounts[m_userName].accountName().toUtf8().constData());
 	}
 
 	emit globMsgProcEmitter.downloadMessageListFinished(m_userName,
@@ -247,7 +248,12 @@ enum TaskDownloadMessageList::Result TaskDownloadMessageList::downloadMessageLis
 #ifdef USE_TRANSACTIONS
 		if (!usedDbs.contains(messageDb)) {
 			usedDbs.insert(messageDb);
-			messageDb->beginTransaction();
+			if (!messageDb->beginTransaction()) {
+				logWarningNL(
+				    "Cannot begin transaction for '%s'.",
+				    userName.toUtf8().constData());
+//				return DL_DB_INS_ERR;
+			}
 		}
 #endif /* USE_TRANSACTIONS */
 
@@ -257,7 +263,7 @@ enum TaskDownloadMessageList::Result TaskDownloadMessageList::downloadMessageLis
 		/* Message is NOT in db (-1), -> insert */
 		if (-1 == dmDbMsgStatus) {
 
-			Task::storeEnvelope(msgDirect, dbSet, item->envelope, NULL);
+			Task::storeEnvelope(msgDirect, dbSet, item->envelope);
 			if (downloadWhole) {
 				TaskDownloadMessage *task;
 				task = new (std::nothrow) TaskDownloadMessage(
@@ -272,13 +278,13 @@ enum TaskDownloadMessageList::Result TaskDownloadMessageList::downloadMessageLis
 		} else {
 
 			/* Update message and envelope only if status has changed. */
-			const int dmNewMsgStatus = convertHexToDecIndex(
+			const int dmNewMsgStatus = IsdsConversion::msgStatusIsdsToDbRepr(
 			     *item->envelope->dmMessageStatus);
 
 			if (dmNewMsgStatus != dmDbMsgStatus) {
 				/* Update envelope */
 				Task::updateEnvelope(msgDirect, *messageDb,
-				    item->envelope, NULL);
+				    item->envelope);
 
 				/*
 				 * Download whole message again if exists in db
@@ -431,11 +437,11 @@ enum TaskDownloadMessageList::Result TaskDownloadMessageList::updateMessageState
 		 * we get proper data from ISDS rather than storing potentially
 		 * guessed values.
 		 */
-		Task::updateEnvelope(msgDirect, *messageDb, envel, NULL);
+		Task::updateEnvelope(msgDirect, *messageDb, envel);
 	} else if (messageDb->msgsUpdateMessageState(dmID,
 	    dmDeliveryTime, dmAcceptanceTime,
 	    envel->dmMessageStatus ?
-	        convertHexToDecIndex(*envel->dmMessageStatus) : 0)) {
+	        IsdsConversion::msgStatusIsdsToDbRepr(*envel->dmMessageStatus) : 0)) {
 		/* Updated message envelope delivery info in db. */
 		logDebugLv0NL(
 		    "Delivery information of message '%" PRId64 "' were updated.",
@@ -453,7 +459,7 @@ enum TaskDownloadMessageList::Result TaskDownloadMessageList::updateMessageState
 		isds_event *item = (isds_event *) event->data;
 		messageDb->msgsInsertUpdateMessageEvent(dmID,
 		    timevalToDbFormat(item->time),
-		    convertEventTypeToString(*item->type),
+		    IsdsConversion::eventTypeToStr(*item->type) + QLatin1String(": "),
 		    item->description);
 		event = event->next;
 	}
