@@ -27,6 +27,7 @@
 #include <QDateTime>
 #include <QString>
 
+#include "src/io/message_db.h"
 #include "src/io/message_db_set.h"
 #include "src/worker/task.h"
 
@@ -47,13 +48,12 @@ public:
 	 *
 	 * @param[in]     userName     Account identifier (user login name).
 	 * @param[in,out] dbSet        Non-null pointer to database container.
-	 * @param[in]     dmId         Message identifier.
-	 * @param[in]     deliveryTime Message delivery time.
-	 * @param[in]     incoming    True if message is received.
+	 * @param[in]     msgId        Message identifier.
+	 * @param[in]     msgDirect    Received or sent.
 	 * @param[in]     delFromIsds  True if also delete from ISDS.
 	 */
 	explicit TaskEraseMessage(const QString &userName, MessageDbSet *dbSet,
-	    qint64 dmId, const QDateTime &deliveryTime, bool incoming,
+	    const MessageDb::MsgId &msgId, enum MessageDirection msgDirect,
 	    bool delFromIsds);
 
 	/*!
@@ -78,9 +78,8 @@ private:
 	 *
 	 * @param[in]     userName     Account identifier (user login name).
 	 * @param[in,out] dbSet        Non-null pointer to database container.
-	 * @param[in]     dmId         Message identifier.
-	 * @param[in]     deliveryTime Message delivery time.
-	 * @param[in]     incoming    True if message is received.
+	 * @param[in]     msgId        Message identifier.
+	 * @param[in]     msgDirect    Received or sent.
 	 * @param[in]     delFromIsds  True if also delete from ISDS.
 	 * @param[out]    error        Error description.
 	 * @param[out]    longError    Long error description.
@@ -88,14 +87,13 @@ private:
 	 */
 	static
 	enum Result eraseMessage(const QString &userName, MessageDbSet *dbSet,
-	    qint64 dmId, const QDateTime &deliveryTime, bool incoming,
+	    const MessageDb::MsgId &msgId, enum MessageDirection msgDirect,
 	    bool delFromIsds, QString &error, QString &longError);
 
 	const QString m_userName; /*!< Account identifier (user login name). */
 	MessageDbSet *m_dbSet; /*!< Pointer to database container. */
-	const qint64 m_dmId; /*!< Message identifier. */
-	const QDateTime m_deliveryTime; /*!< Message delivery time. */
-	const bool m_incoming; /*!< True if message is received. */
+	const MessageDb::MsgId m_msgId; /*!< Message identifier. */
+	enum MessageDirection m_msgDirect; /*!< Received or sent. */
 	const bool m_delFromIsds; /*!< True is also delete from ISDS. */
 };
 
