@@ -31,7 +31,7 @@
 #include "src/io/dbs.h"
 #include "src/io/isds_sessions.h"
 #include "src/log/log.h"
-#include "src/models/accounts_model.h"
+#include "src/settings/accounts.h"
 #include "src/worker/message_emitter.h"
 #include "src/worker/task_authenticate_message.h"
 #include "src/worker/task_import_zfo.h"
@@ -115,12 +115,12 @@ enum TaskImportZfo::ZfoType TaskImportZfo::determineFileType(
 	}
 
 	struct isds_message *message = loadZfoFile(dummySession, fileName,
-	    ImportZFODialog::IMPORT_MESSAGE_ZFO);
+	    Imports::IMPORT_MESSAGE);
 	if (NULL != message) {
 		zfoType = ZT_MESSAGE;
 	} else {
 		message = loadZfoFile(dummySession, fileName,
-		    ImportZFODialog::IMPORT_DELIVERY_ZFO);
+		    Imports::IMPORT_DELIVERY);
 		if(NULL != message) {
 			zfoType = ZT_DELIVERY_INFO;
 		} else {
@@ -144,11 +144,11 @@ enum TaskImportZfo::ZfoType TaskImportZfo::determineFileType(
  */
 static
 enum TaskImportZfo::Result loadZfo(const QString &fileName,
-    enum ImportZFODialog::ZFOtype zfoType, struct isds_message **msgPtr)
+    enum Imports::Type zfoType, struct isds_message **msgPtr)
 {
 	Q_ASSERT((NULL != msgPtr) && (NULL == *msgPtr));
-	Q_ASSERT((ImportZFODialog::IMPORT_MESSAGE_ZFO == zfoType) ||
-	    (ImportZFODialog::IMPORT_DELIVERY_ZFO == zfoType));
+	Q_ASSERT((Imports::IMPORT_MESSAGE == zfoType) ||
+	    (Imports::IMPORT_DELIVERY == zfoType));
 
 	struct isds_message *message = NULL;
 
@@ -220,8 +220,7 @@ enum TaskImportZfo::Result TaskImportZfo::importMessageZfoSingle(
 		    "database file could not be accessed or created.");
 		return TaskImportZfo::IMP_ERR;
 	}
-	const QString accountName(
-	    AccountModel::globAccounts[acnt.userName].accountName());
+	const QString accountName(globAccounts[acnt.userName].accountName());
 	if (-1 != messageDb->msgsStatusIfExists(dmId)) {
 		resultDesc = QObject::tr("Message '%1' already exists in "
 		    "the local database, account '%2'.").
@@ -256,9 +255,9 @@ enum TaskImportZfo::Result TaskImportZfo::importMessageZfoSingle(
 
 	/* Store envelope and message. */
 	if ((Q_SUCCESS != Task::storeEnvelope(direct, *(acnt.messageDbSet),
-	                      message->envelope, NULL)) ||
+	                      message->envelope)) ||
 	    (Q_SUCCESS != Task::storeMessage(true, direct, *(acnt.messageDbSet),
-	                      message, "", NULL))) {
+	                      message, ""))) {
 		resultDesc = QObject::tr("File has not been imported because "
 		    "an error was detected during insertion process.");
 		return TaskImportZfo::IMP_DB_INS_ERR;
@@ -279,7 +278,7 @@ enum TaskImportZfo::Result TaskImportZfo::importMessageZfo(
 
 	{
 		enum TaskImportZfo::Result res = loadZfo(fileName,
-		    ImportZFODialog::IMPORT_MESSAGE_ZFO, &message);
+		    Imports::IMPORT_MESSAGE, &message);
 		if (IMP_SUCCESS != res) {
 			Q_ASSERT(NULL == message);
 			resultDesc = QObject::tr("Wrong ZFO format. This file "
@@ -369,8 +368,7 @@ enum TaskImportZfo::Result TaskImportZfo::importDeliveryZfoSingle(
 
 	MessageDb *messageDb = acnt.messageDbSet->accessMessageDb(deliveryTime,
 	    false);
-	const QString accountName(
-	    AccountModel::globAccounts[acnt.userName].accountName());
+	const QString accountName(globAccounts[acnt.userName].accountName());
 	if ((NULL == messageDb) ||
 	    (-1 == messageDb->msgsStatusIfExists(dmId))) {
 		/* Corresponding message does not exist in database. */
@@ -436,7 +434,7 @@ enum TaskImportZfo::Result TaskImportZfo::importDeliveryZfo(
 
 	{
 		enum TaskImportZfo::Result res = loadZfo(fileName,
-		    ImportZFODialog::IMPORT_DELIVERY_ZFO, &message);
+		    Imports::IMPORT_DELIVERY, &message);
 		if (IMP_SUCCESS != res) {
 			Q_ASSERT(NULL == message);
 			resultDesc = QObject::tr("Wrong ZFO format. This file "
